<?php

$LANG = array(
    'organization' => 'Organizacija',
    'name' => 'Ime',
    'website' => 'Web adresa',
    'work_phone' => 'Telefon',
    'address' => 'Adresa',
    'address1' => 'Ulica',
    'address2' => 'Sprat/soba',
    'city' => 'Grad',
    'state' => 'Okrug',
    'postal_code' => 'Poštanski broj',
    'country_id' => 'Zemlja',
    'contacts' => 'Kontakti',
    'first_name' => 'Ime',
    'last_name' => 'Prezime',
    'phone' => 'Telefon',
    'email' => 'E-pošta',
    'additional_info' => 'Dodatne informacije',
    'payment_terms' => 'Uslovi plaćanja',
    'currency_id' => 'Valuta',
    'size_id' => 'Veličina poduzeća',
    'industry_id' => 'Delatnost',
    'private_notes' => 'Privatne beleške',
    'invoice' => 'Račun',
    'client' => 'Klijent',
    'invoice_date' => 'Datum računa',
    'due_date' => 'Datum dospeća',
    'invoice_number' => 'Broj računa',
    'invoice_number_short' => 'Račun #',
    'po_number' => 'Broj narudžbe',
    'po_number_short' => 'NN #',
    'frequency_id' => 'Koliko često',
    'discount' => 'Popust',
    'taxes' => 'Porezi',
    'tax' => 'Porez',
    'item' => 'Stavka',
    'description' => 'Opis',
    'unit_cost' => 'Jedinična cena',
    'quantity' => 'Količina',
    'line_total' => 'Ukupno',
    'subtotal' => 'Sveukupno',
    'paid_to_date' => 'Plaćeno na vreme',
    'balance_due' => 'Stanje duga',
    'invoice_design_id' => 'Dizajn',
    'terms' => 'Uslovi',
    'your_invoice' => 'Vaš račun',
    'remove_contact' => 'Ukloni kontakt',
    'add_contact' => 'Dodaj kontakt',
    'create_new_client' => 'Kreiraj novog klijenta',
    'edit_client_details' => 'Izmeni detalje klijenta',
    'enable' => 'Omogući',
    'learn_more' => 'Više informacija',
    'manage_rates' => 'Upravljanje ratama',
    'note_to_client' => 'Beleška klijentu',
    'invoice_terms' => 'Uslovi računa',
    'save_as_default_terms' => 'Snimi kao podrazumevane uslove',
    'download_pdf' => 'Preuzmi PDF',
    'pay_now' => 'Plati odmah',
    'save_invoice' => 'Snimi račun',
    'clone_invoice' => 'Kloniraj u račun',
    'archive_invoice' => 'Arhiviraj račun',
    'delete_invoice' => 'Obriši račun',
    'email_invoice' => 'Pošalji e-poštom',
    'enter_payment' => 'Unesi uplatu',
    'tax_rates' => 'Porezne stope',
    'rate' => 'Stopa',
    'settings' => 'Postavke',
    'enable_invoice_tax' => 'Omogući specificiranje <b>poreza na računu</b>',
    'enable_line_item_tax' => 'Omogući  specifikaciju <b>poreza na stavci</b>',
    'dashboard' => 'Kontrolna tabla',
    'dashboard_totals_in_all_currencies_help' => 'Napomena: dodajte :link sa nazivom ":name" za prikaz ukupnih vrednosti koristeći jedinstvenu baznu valutu.',
    'clients' => 'Klijenti',
    'invoices' => 'Računi',
    'payments' => 'Uplate',
    'credits' => 'Krediti',
    'history' => 'Istorija',
    'search' => 'Pretraga',
    'sign_up' => 'Prijava',
    'guest' => 'Gost',
    'company_details' => 'Detalji preduzeća',
    'online_payments' => 'Online uplate',
    'notifications' => 'Obaveštenja',
    'import_export' => 'Uvoz i Izvoz',
    'done' => 'Završeno',
    'save' => 'Snimi',
    'create' => 'Kreiraj',
    'upload' => 'Upload',
    'import' => 'Uvoz',
    'download' => 'Preuzmi',
    'cancel' => 'Odustani',
    'close' => 'Zatvori',
    'provide_email' => 'Unesite ispravnu email adresu',
    'powered_by' => 'Powered by',
    'no_items' => 'Nema stavki',
    'recurring_invoices' => 'Ponavljajući računi',
    'recurring_help' => '<p>Automatically send clients the same invoices weekly, bi-monthly, monthly, quarterly or annually. </p>
        <p>Use :MONTH, :QUARTER or :YEAR for dynamic dates. Basic math works as well, for example :MONTH-1.</p>
        <p>Examples of dynamic invoice variables:</p>
        <ul>
          <li>"Gym membership for the month of :MONTH" >> "Gym membership for the month of July"</li>
          <li>":YEAR+1 yearly subscription" >> "2015 Yearly Subscription"</li>
          <li>"Retainer payment for :QUARTER+1" >> "Retainer payment for Q2"</li>
        </ul>',
    'recurring_quotes' => 'Ponavljajuća ponuda',
    'in_total_revenue' => 'ukupni prihod',
    'billed_client' => 'fakturisani klijent',
    'billed_clients' => 'fakturisani klijenti',
    'active_client' => 'aktivni klijent',
    'active_clients' => 'aktivni klijenti',
    'invoices_past_due' => 'Računi van valute',
    'upcoming_invoices' => 'Dolazni računi',
    'average_invoice' => 'Prosečni račun',
    'archive' => 'Arhiva',
    'delete' => 'Obriši',
    'archive_client' => 'Arhiviraj klijenta',
    'delete_client' => 'Obriši klijenta',
    'archive_payment' => 'Arhiviraj uplatu',
    'delete_payment' => 'Obriši uplatu',
    'archive_credit' => 'Arhiviraj kredit',
    'delete_credit' => 'Obriši kredit',
    'show_archived_deleted' => 'Prikaži arhivirano/obrisano',
    'filter' => 'Filter',
    'new_client' => 'Novi klijent',
    'new_invoice' => 'Novi račun',
    'new_payment' => 'Unesi plaćanje',
    'new_credit' => 'Unesi kredit',
    'contact' => 'Kontakt',
    'date_created' => 'Datum kreiranja',
    'last_login' => 'Zadnja prijava',
    'balance' => 'Stanje',
    'action' => 'Akcija',
    'status' => 'Status',
    'invoice_total' => 'Račun sveukupno',
    'frequency' => 'Frekvencija',
    'range' => 'Opseg',
    'start_date' => 'Početni datum',
    'end_date' => 'Završni datum',
    'transaction_reference' => 'Referenca transakcije',
    'method' => 'Metoda',
    'payment_amount' => 'Iznos uplate',
    'payment_date' => 'Datum uplate',
    'credit_amount' => 'Iznos kredita',
    'credit_balance' => 'Stanje kredita',
    'credit_date' => 'Datum kredita',
    'empty_table' => 'Nema dostupnih podataka u tabeli',
    'select' => 'Odaberi',
    'edit_client' => 'Uredi klijenta',
    'edit_invoice' => 'Uredi račun',
    'create_invoice' => 'Kreiraj račun',
    'enter_credit' => 'Unesi kredit',
    'last_logged_in' => 'Zadnja prijava na',
    'details' => 'Detalji',
    'standing' => 'Stanje',
    'credit' => 'Kredit',
    'activity' => 'Aktivnost',
    'date' => 'Datum',
    'message' => 'Poruka',
    'adjustment' => 'Prilagođavanje',
    'are_you_sure' => 'Da li ste sigurni?',
    'payment_type_id' => 'Tip uplate',
    'amount' => 'Iznos',
    'work_email' => 'E-pošta',
    'language_id' => 'Jezik',
    'timezone_id' => 'Vremenska zona',
    'date_format_id' => 'Date Format',
    'datetime_format_id' => 'Datum/Vreme format',
    'users' => 'Korisnici',
    'localization' => 'Lokalizacija',
    'remove_logo' => 'Ukloni logo',
    'logo_help' => 'Podržano: JPEG, GIF i PNG',
    'payment_gateway' => 'Kanal naplate',
    'gateway_id' => 'Kanal',
    'email_notifications' => 'Obaveštenja e-poštom',
    'email_sent' => 'Obavesti me e-poštom kada je račun <b>poslat</b>',
    'email_viewed' => 'Obavesti me e-poštom kada je račun <b>pregledan</b>',
    'email_paid' => 'Obavesti me e-poštom kada je račun <b>plaćen</b>',
    'site_updates' => 'Ažuriranja',
    'custom_messages' => 'Prilagođene poruke',
    'default_email_footer' => 'Postavi podrazumevani <b>potpis e-pošte</b>',
    'select_file' => 'Mollim odaberite datoteku',
    'first_row_headers' => 'Koristi prvi red kao naslovni',
    'column' => 'Kolona',
    'sample' => 'Uzorak',
    'import_to' => 'Uvezi u',
    'client_will_create' => 'klijent će biti kreiran',
    'clients_will_create' => 'klijenti će biti kreirani',
    'email_settings' => 'Postavke e-pošte',
    'client_view_styling' => 'Stil pregleda klijenta',
    'pdf_email_attachment' => 'Zakači PDF',
    'custom_css' => 'Prilagođeni CSS',
    'import_clients' => 'Uvezi podatke klijenta',
    'csv_file' => 'CSV datoteka',
    'export_clients' => 'Izvezi podatke klijenta',
    'created_client' => 'Klijent je uspešno kreiran',
    'created_clients' => 'Uspešno kreirano :count kijenata',
    'updated_settings' => 'Postavke su uspešno ažurirane',
    'removed_logo' => 'Logo je uspešno uklonjen',
    'sent_message' => 'Poruka je uspešno poslata',
    'invoice_error' => 'Molimo proverite da li ste odaberali klijenta i korigujte greške',
    'limit_clients' => 'Nažalost, ovime ćete preći limit od :count klijenata',
    'payment_error' => 'Došlo je do greške pri procesiranju vaše uplate. Molimo pokušajte kasnije.',
    'registration_required' => 'Molimo prijavite se pre slanja računa e-poštom',
    'confirmation_required' => 'Molimo Vas da potvrdite adresu vaše e-pošte, :link za ponovno slanje konfirmacione e-poruke.',
    'updated_client' => 'Uspešno ažuriranje klijenta',
    'archived_client' => 'Uspešno arhiviran klijent',
    'archived_clients' => 'Uspešno arhivirano :count klijenata',
    'deleted_client' => 'Uspešno obrisan klijent',
    'deleted_clients' => 'Uspešno obrisano :count klijenata',
    'updated_invoice' => 'Uspešno ažuriran račun',
    'created_invoice' => 'Uspešno kreiran račun',
    'cloned_invoice' => 'Uspešno kloniran račun',
    'emailed_invoice' => 'Račun uspešno poslat e-poštom',
    'and_created_client' => 'i kreiran račun',
    'archived_invoice' => 'Uspešno arhiviran račun',
    'archived_invoices' => 'Uspešno arhivirano :count računa',
    'deleted_invoice' => 'Uspešno obrisan račun',
    'deleted_invoices' => 'Uspešno obrisano :count računa',
    'created_payment' => 'Uspešno kreirana uplata',
    'created_payments' => 'Uspešno kreirano :count uplata',
    'archived_payment' => 'Uspešno arhivirana uplata',
    'archived_payments' => 'Uspešno arhivirana :count uplata',
    'deleted_payment' => 'Uspešno obrisana uplata',
    'deleted_payments' => 'Uspešno obrisano :count uplata',
    'applied_payment' => 'Uspešno primjenjena uplata',
    'created_credit' => 'Uspešno kreiran kredit',
    'archived_credit' => 'Uspešno arhiviran kredit',
    'archived_credits' => 'Uspešno arhivirano :count kredita',
    'deleted_credit' => 'Uspešno obrisan kredit',
    'deleted_credits' => 'Uspešno obrisano :count kredita',
    'imported_file' => 'Uspešno uvezena datoteka',
    'updated_vendor' => 'Uspešno ažuriran dobavljač',
    'created_vendor' => 'Uspešno kreiran dobavljač',
    'archived_vendor' => 'Uspešno arhiviran dobavljač',
    'archived_vendors' => 'Uspešno arhivirano :count dobavljača',
    'deleted_vendor' => 'Uspešno obrisan dobavljač',
    'deleted_vendors' => 'Uspešno obrisano :count dobavljača',
    'confirmation_subject' => 'Invoice Ninja odobravanje računa',
    'confirmation_header' => 'Odobrenje računa',
    'confirmation_message' => 'Kliknite na link ispod da biste odobrili vaš račun.',
    'invoice_subject' => 'Novi račun :number od :account',
    'invoice_message' => 'Za pregled vašeg računa na :amount, kliknite na link ispod.',
    'payment_subject' => 'Primljena uplata',
    'payment_message' => 'Hvala vam na vašoj uplati od :amount.',
    'email_salutation' => 'Poštovani/a :name,',
    'email_signature' => 'Sa poštovanjem,',
    'email_from' => 'Invoice Ninja tim',
    'invoice_link_message' => 'Za pregled računa kliknite na link ispod:',
    'notification_invoice_paid_subject' => ':client je platio račun :invoice',
    'notification_invoice_sent_subject' => 'Račun :invoice je poslat :client',
    'notification_invoice_viewed_subject' => ':client je pregledao račun :invoice',
    'notification_invoice_paid' => 'Uplata u iznosu :amount je izvršena od strane :client prema računu :invoice.',
    'notification_invoice_sent' => 'Sledećem klijentu :client je poslat e-poštom račun :invoice na iznos :amount.',
    'notification_invoice_viewed' => 'Sledeći klijent :client je pregledao račun :invoice na iznos :amount.',
    'reset_password' => 'Možete resetirati zaporku za pristup svom računu klikom na tipku:',
    'secure_payment' => 'Sigurna uplata',
    'card_number' => 'Broj kartice',
    'expiration_month' => 'Mesec isteka',
    'expiration_year' => 'Godina isteka',
    'cvv' => 'CVV',
    'logout' => 'Odjava',
    'sign_up_to_save' => 'Prijavite se kako bi sačuvali promene',
    'agree_to_terms' => 'Slažem se sa  :terms',
    'terms_of_service' => 'Uslovi korištenja usluge',
    'email_taken' => 'Ova adresa e-pošte je već registrovana',
    'working' => 'Rad u toku',
    'success' => 'Uspeh',
    'success_message' => 'Uspešno ste se registrovali! Kliknite na link ispod da biste potvrdili vašu email adresu.',
    'erase_data' => 'Vaš nalog nije registrovan, ovo će trajno izbrisati vaše podatke.',
    'password' => 'Lozinka',
    'pro_plan_product' => 'Pro Plan',
    'pro_plan_success' => 'Hvala vam na odabiru Invoice Ninja Pro plana!<p/>&nbsp;<br/>
                          <b>Sledeći koraci</b><p/>Račun je poslat na adresu e-pošte povezanu
                          sa vašim korisničkim računom. Za otključavanje svih naprednih
                          Pro mogućnosti, molimo pratite upute za plaćanje godišnje pretplate
                          za  Invoice Ninja Pro plan.<p/>
                          Ne možete naći račun? Trebate dodatnu pomoć? Sa zadovoljstvom ćemo pomoći
                          -- pošaljite nam e-poštu na contact@invoiceninja.com',
    'unsaved_changes' => 'Imate nesačuvanih promena',
    'custom_fields' => 'Prilagođena polja',
    'company_fields' => 'Polja poduzeća',
    'client_fields' => 'Polja klijenta',
    'field_label' => 'Oznaka polja',
    'field_value' => 'Vrednost polja',
    'edit' => 'Uredi',
    'set_name' => 'Postavite ime preduzeća',
    'view_as_recipient' => 'Pregledajte kao primalac',
    'product_library' => 'Registar proizvoda',
    'product' => 'Proizvod',
    'products' => 'Proizvodi',
    'fill_products' => 'Proizvodi sa samoispunom',
    'fill_products_help' => 'Odabir proizvoda će automatski <b>ispuniti opis i cijenu</b>',
    'update_products' => 'Proizvodi sa autoažuriranjem',
    'update_products_help' => 'Ažuriranje računa automatski <b>ažurirati registar proizvoda</b>',
    'create_product' => 'Dodaj proizvod',
    'edit_product' => 'Uredi proizvod',
    'archive_product' => 'Arhiviraj proizvod',
    'updated_product' => 'Proizvod je uspešno ažuriran',
    'created_product' => 'Proizvod je uspešno kreiran',
    'archived_product' => 'Proizvod je uspešno arhiviran',
    'pro_plan_custom_fields' => ':link za omogućavanje prilagođenih polja aktivacijom Pro plana',
    'advanced_settings' => 'Napredne postavke',
    'pro_plan_advanced_settings' => ':link za omogućavanje naprednih postavki aktivacijom Pro plana',
    'invoice_design' => 'Dizajn računa',
    'specify_colors' => 'Odabir boja',
    'specify_colors_label' => 'Odaberite boje korištenje u računu',
    'chart_builder' => 'Menadžer grafikona',
    'ninja_email_footer' => 'Kreirao :site | Kreiraj. Pošalji. Budi plaćen.',
    'go_pro' => 'Go Pro',
    'quote' => 'Ponuda',
    'quotes' => 'Ponude',
    'quote_number' => 'Broj ponude',
    'quote_number_short' => 'Ponuda #',
    'quote_date' => 'Datum ponude',
    'quote_total' => 'Ukupno predračuna',
    'your_quote' => 'Vaš predračun',
    'total' => 'Sveukupno',
    'clone' => 'Kloniraj',
    'new_quote' => 'Novi predračun',
    'create_quote' => 'Kreiraj predračun',
    'edit_quote' => 'Uredi predračun',
    'archive_quote' => 'Arhiviraj predračun',
    'delete_quote' => 'Obriši predračun',
    'save_quote' => 'Sačuvaj predračun',
    'email_quote' => 'Šalji predračun e-poštom',
    'clone_quote' => 'Kloniraj u predračun',
    'convert_to_invoice' => 'Konvertuj u račun',
    'view_invoice' => 'Pregled računa',
    'view_client' => 'Pregled klijenta',
    'view_quote' => 'Pregled predračuna',
    'updated_quote' => 'Predračun je uspešno ažuriran',
    'created_quote' => 'Predračun je uspešno kreiran',
    'cloned_quote' => 'Predračun je uspešno kloniran',
    'emailed_quote' => 'Predračun je uspešno poslan e-poštom',
    'archived_quote' => 'Predračun je uspešno arhiviran',
    'archived_quotes' => 'Uspešno arhivirano :count predračuna',
    'deleted_quote' => 'Predračun uspešno obrisan',
    'deleted_quotes' => 'Uspešno obrisano :count predračuna',
    'converted_to_invoice' => 'Predračun je uspešno pretvoren u račun',
    'quote_subject' => 'Nov predračun :number od :account',
    'quote_message' => 'Za pregled vašeg predračuna na iznos :amount, kliknite na link ispod.',
    'quote_link_message' => 'Za pregled predračuna vašeg klijenta kliknite na link ispod:',
    'notification_quote_sent_subject' => 'Predračun :invoice je poslat :client',
    'notification_quote_viewed_subject' => 'Predračun :invoice je pregledan od strane :client',
    'notification_quote_sent' => 'Klijentu :client je e-poštom poslat predračun :invoice na iznos :amount.',
    'notification_quote_viewed' => 'Klijent :client je pregledao ppredračun  :invoice na iznos :amount.',
    'session_expired' => 'Vaša sesija je istekla.',
    'invoice_fields' => 'Polja računa',
    'invoice_options' => 'Opcije računa',
    'hide_paid_to_date' => 'Sakrij datum plaćanja',
    'hide_paid_to_date_help' => 'Prikažite "Datum plaćanja" na računima, onda kada je uplata primljena.',
    'charge_taxes' => 'Naplati poreze',
    'user_management' => 'Upravljanje korisnicima',
    'add_user' => 'Dodaj korisnika',
    'send_invite' => 'Pošalji Pozivnicu',
    'sent_invite' => 'Uspešno poslata pozivnica',
    'updated_user' => 'Korisnik je uspešno ažuriran',
    'invitation_message' => 'Dobili ste pozivnicu od :invitor.',
    'register_to_add_user' => 'Molimo prijavite se za dodavanje korisnika',
    'user_state' => 'Stanje',
    'edit_user' => 'Uredi korisnika',
    'delete_user' => 'Obriši korisnika',
    'active' => 'Aktivan',
    'pending' => 'Na čekanju',
    'deleted_user' => 'Korisnik je uspešno obrisan',
    'confirm_email_invoice' => 'Da li sigurno želite poslati ovaj račun e-poštom?',
    'confirm_email_quote' => 'Da li sigurno želite poslati ovau ponudu e-poštom?',
    'confirm_recurring_email_invoice' => 'Da li ste sigurni da želite poslati ovaj račun e-poštom?',
    'confirm_recurring_email_invoice_not_sent' => 'Da li sigurno želite da  pokrenete ponavljanje ?',
    'cancel_account' => 'Izbriši nalog',
    'cancel_account_message' => 'Upozorenje: Ovo će trajno izbrisati vaš nalog.',
    'go_back' => 'Idi natrag',
    'data_visualizations' => 'Vizualizacije podataka',
    'sample_data' => 'Prikaz demo podataka',
    'hide' => 'Sakrij',
    'new_version_available' => 'Nova verzija :releases_link je dostupna. Vi koristite v:user_version, a najnovija je v:latest_version',
    'invoice_settings' => 'Postavke računa',
    'invoice_number_prefix' => 'Prefiks broja računa',
    'invoice_number_counter' => 'Brojač računa',
    'quote_number_prefix' => 'Prefiks broja ponude',
    'quote_number_counter' => 'Brojač ponuda',
    'share_invoice_counter' => 'Deljeni brojač računa',
    'invoice_issued_to' => 'Račun izdat',
    'invalid_counter' => 'Za izbegavanje mogućih konflikata molimo postavite prefiks na broju računa i ponuda',
    'mark_sent' => 'Označi kao poslato',
    'gateway_help_1' => ':link za pristup na Authorize.net.',
    'gateway_help_2' => ':link za pristup na Authorize.net.',
    'gateway_help_17' => ':link za pristup vašem PayPal API potpisu.',
    'gateway_help_27' => ':link to sign up for 2Checkout.com. To ensure payments are tracked set :complete_link as the redirect URL under Account > Site Management in the 2Checkout portal.',
    'gateway_help_60' => ':link za kreiranje WePay naloga.',
    'more_designs' => 'Više dizajna',
    'more_designs_title' => 'Dodatni dizajni računa',
    'more_designs_cloud_header' => 'Nadogradite na Pro za više dizajna računa',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Kupi',
    'bought_designs' => 'Uspešno dodani dizajni računa',
    'sent' => 'Poslato',
    'vat_number' => 'PIB',
    'timesheets' => 'Vremenski raspored',
    'payment_title' => 'Unesite svoju adresu računa i informacije kreditne kartice',
    'payment_cvv' => '*U pitanju su 3-4 cifre sa poleđine kartice',
    'payment_footer1' => '*Adresa računa mora se poklapati s adresom na kreditnoj kartici.',
    'payment_footer2' => '*Molimo kliknite "PLATI ODMAH" samo jednom - transakcija se može izvršavati i do 1 minuta.',
    'id_number' => 'Matični broj',
    'white_label_link' => 'Bela oznaka',
    'white_label_header' => 'Bela oznaka',
    'bought_white_label' => 'Uspešno je omogućena licenca za bele oznake',
    'white_labeled' => 'Označeno belom oznakom',
    'restore' => 'Vrati',
    'restore_invoice' => 'Vrati račun',
    'restore_quote' => 'Vrati predračun',
    'restore_client' => 'Vrati klijenta',
    'restore_credit' => 'Vrati kredit',
    'restore_payment' => 'Vrati uplatu',
    'restored_invoice' => 'Uspešno vraćen račun',
    'restored_quote' => 'Uspešno vraćen predračun',
    'restored_client' => 'Uspešno vraćen klijent',
    'restored_payment' => 'Uspešno vraćena uplata',
    'restored_credit' => 'Uspešno vraćen kredit',
    'reason_for_canceling' => 'Pomozite nam da unapredimo web stranicu informacijom zašto odlazite.',
    'discount_percent' => 'Procenat',
    'discount_amount' => 'Iznos',
    'invoice_history' => 'Istorija računa',
    'quote_history' => 'Istorija ponuda',
    'current_version' => 'Trenutna verzija',
    'select_version' => 'Izaberi verziju',
    'view_history' => 'Pregled istorije',
    'edit_payment' => 'Izmeni uplatu',
    'updated_payment' => 'Uspešno ažurirana uplata',
    'deleted' => 'Obrisano',
    'restore_user' => 'Obnovi korisnika',
    'restored_user' => 'Uspešno obnovljen korisnik',
    'show_deleted_users' => 'Prikaži obrisane korisnike',
    'email_templates' => 'Šabloni e-pošte',
    'invoice_email' => 'E-pošta računa',
    'payment_email' => 'E-pošta uplate',
    'quote_email' => 'E-pošta ponuda',
    'reset_all' => 'Resetuj sve',
    'approve' => 'Odobri',
    'token_billing_type_id' => 'Token naplata',
    'token_billing_help' => 'Sačuvajte detalje plaćanja sa WePay, Stripe, Braintree ili GoCardless.',
    'token_billing_1' => 'Onemogućeno',
    'token_billing_2' => 'Opt-in - odabir je prikazan ali nije selektovan',
    'token_billing_3' => 'Opt-out - odabir je prikazan i selektovan',
    'token_billing_4' => 'Uvek',
    'token_billing_checkbox' => 'Snimi detalje kreditne kartice',
    'view_in_gateway' => 'View in :gateway',
    'use_card_on_file' => 'Use Card on File',
    'edit_payment_details' => 'Izmeni detalje plaćanja',
    'token_billing' => 'Izmeni detalje kartice',
    'token_billing_secure' => 'Podaci se sigurnosno skladište od strane :link',
    'support' => 'Podrška',
    'contact_information' => 'Kontakt informacije',
    '256_encryption' => '256-bitna enkripcija',
    'amount_due' => 'Dospeli iznos',
    'billing_address' => 'Adresa računa',
    'billing_method' => 'Metod naplate',
    'order_overview' => 'Pregled porudžbenice',
    'match_address' => '*Adresa se mora poklapati s adresom kreditne kartice.',
    'click_once' => '*Molimo kliknite "PLATI ODMAH" samo jednom - transakcija se može izvršavati i do 1 minuta.',
    'invoice_footer' => 'Podnožje računa',
    'save_as_default_footer' => 'Snimi kao podrazumevano podnožje',
    'token_management' => 'Upravljanje tokenima',
    'tokens' => 'Tokeni',
    'add_token' => 'Dodaj token',
    'show_deleted_tokens' => 'Prikaži obrisane tokene',
    'deleted_token' => 'Uspešno obrisan token',
    'created_token' => 'Uspešno kreiran token',
    'updated_token' => 'Uspešno ažuriran token',
    'edit_token' => 'Izmeni token',
    'delete_token' => 'Obriši token',
    'token' => 'Token',
    'add_gateway' => 'Dodaj kapiju za plaćanje',
    'delete_gateway' => 'Obriši kapiju za plaćanje',
    'edit_gateway' => 'Uredi kanal',
    'updated_gateway' => 'Uspešno ažuriran kanal',
    'created_gateway' => 'Uspešno kreiran kanal',
    'deleted_gateway' => 'Uspešno obrisan kanal',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Kreditna kartica',
    'change_password' => 'Promeni lozinku',
    'current_password' => 'Trenutna lozinka',
    'new_password' => 'Nova lozinka',
    'confirm_password' => 'Potvrdi lozinku',
    'password_error_incorrect' => 'Trenutna lozinka nije ispravna.',
    'password_error_invalid' => 'Nova lozinka je neispravna.',
    'updated_password' => 'Uspešno ažurirana lozinka',
    'api_tokens' => 'API tokeni',
    'users_and_tokens' => 'Korisnici & tokeni',
    'account_login' => 'Korisnička prijava',
    'recover_password' => 'Povratite vašu lozinku',
    'forgot_password' => 'Zaboravili ste lozinku?',
    'email_address' => 'Adresa e-pošte',
    'lets_go' => 'Krenimo',
    'password_recovery' => 'Obnavljanje lozinke',
    'send_email' => 'Send Email',
    'set_password' => 'Postavi lozinke',
    'converted' => 'Konvertovano',
    'email_approved' => 'Pošalji mi e-poštu kada je predračun <b>odobren</b>',
    'notification_quote_approved_subject' => 'Predračun :invoice je odobren od strane :client',
    'notification_quote_approved' => 'Sledeći klijent  :client je odobrio predračun :invoice na iznos :amount.',
    'resend_confirmation' => 'Ponovi slanje potvrdne email poruke',
    'confirmation_resent' => 'E-pošta za potvdu je ponovo poslata',
    'gateway_help_42' => ':link za prijavu na BitPay.<br/>Beleška: koristite tradicionalni API ključ, umjesto API tokena.',
    'payment_type_credit_card' => 'Kreditna kartica',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Baza znanja',
    'partial' => 'Partial/Deposit',
    'partial_remaining' => ':partial od :balance',
    'more_fields' => 'Više polja',
    'less_fields' => 'Manje polja',
    'client_name' => 'Ime klijenta',
    'pdf_settings' => 'PDF postavke',
    'product_settings' => 'Postavke proizvoda',
    'auto_wrap' => 'Auto formatiranje stavke',
    'duplicate_post' => 'Pozor: prethodna stranica je poslata dvaput. Drugo slanje će biti ignorisano.',
    'view_documentation' => 'Pregled dokumentacije',
    'app_title' => 'Slobodno fakturisanje otvorenim kodom.',
    'app_description' => 'Invoice Ninja je slobodno rešenje otvorenog koda za fakturisanje i upravljanje klijentima. Pomoću Invoice Ninje možete jednostavno izrađivati i slati kreativne račune sa bilo kojeg uređaja koji ima pristup Internetu. Vaši klijenti mogu ispisivati račune, preuzeti ih kao pdf datoteke i čak vam platiti online unutar istog sistema.',
    'rows' => 'redovi',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Poddomena',
    'provide_name_or_email' => 'Please provide a name or email',
    'charts_and_reports' => 'Karte & Izveštaji',
    'chart' => 'Karte',
    'report' => 'Izveštaji',
    'group_by' => 'Grupiši po',
    'paid' => 'Plaćeno',
    'enable_report' => 'Omogući izveštaj',
    'enable_chart' => 'Grafikon',
    'totals' => 'Totali',
    'run' => 'Pokreni',
    'export' => 'Izvoz',
    'documentation' => 'Dokumentacija',
    'zapier' => 'Zapier',
    'recurring' => 'Ponavljajući računi',
    'last_invoice_sent' => 'Poslednji račun poslat :date',
    'processed_updates' => 'Uspešno završeno ažuriranje',
    'tasks' => 'Zadaci',
    'new_task' => 'Novi zadatak',
    'start_time' => 'Početno vreme',
    'created_task' => 'Uspešno kreiran zadatak',
    'updated_task' => 'Uspešno ažuriran zadatak',
    'edit_task' => 'Uredi zadatak',
    'clone_task' => 'Kloniraj zadatak',
    'archive_task' => 'Arhiviraj zadatak',
    'restore_task' => 'Obnovi zadatak',
    'delete_task' => 'Obriši zadatak',
    'stop_task' => 'Završi zadatak',
    'time' => 'Vreme',
    'start' => 'Početak',
    'stop' => 'Završetak',
    'now' => 'Sada',
    'timer' => 'Štoperica',
    'manual' => 'Ručno',
    'date_and_time' => 'Datum & vreme',
    'second' => 'Sekunda',
    'seconds' => 'Sekunde',
    'minute' => 'Minuta',
    'minutes' => 'Minute',
    'hour' => 'Sati',
    'hours' => 'Sati',
    'task_details' => 'Detalji zadatka',
    'duration' => 'Trajanje',
    'time_log' => 'Vremenski zapisi',
    'end_time' => 'Vreme završetka',
    'end' => 'Kraj',
    'invoiced' => 'Fakturisano',
    'logged' => 'Logovano',
    'running' => 'Pokrenuto',
    'task_error_multiple_clients' => 'Zadaci ne mogu pripadati različitim klijentima',
    'task_error_running' => 'Molimo najpre dovršite izvođenje zadatka',
    'task_error_invoiced' => 'Zadaci su več fakturisani',
    'restored_task' => 'Uspešno obnovljen zadatak',
    'archived_task' => 'Uspešno arhiviran zadatak',
    'archived_tasks' => 'Uspešno arhivirano :count zadataka',
    'deleted_task' => 'Uspešno obrisan zadatak',
    'deleted_tasks' => 'Uspešno obrisano :count zadataka',
    'create_task' => 'Kreiraj zadatak',
    'stopped_task' => 'Uspešno završen zadatak',
    'invoice_task' => 'Fakturiši zadatak',
    'invoice_labels' => 'Oznake računa',
    'prefix' => 'Prefiks',
    'counter' => 'Brojač',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link za prijavu na Dwolla',
    'partial_value' => 'Mora biti veće od nula i manje od sume',
    'more_actions' => 'Više akcija',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Nadogradite odmah!',
    'pro_plan_feature1' => 'Kreirajte neograničeno klijenata',
    'pro_plan_feature2' => 'Pristup na 10 izvrsnih dizajna računa',
    'pro_plan_feature3' => 'Prilagođeni URL - "VašBrand.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Uklonite "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Višekorisnički pristup & praćenje aktivnosti',
    'pro_plan_feature6' => 'Kreiranje ponuda & predračuna',
    'pro_plan_feature7' => 'Prilagođavanje naslova polja računa & numerisanje',
    'pro_plan_feature8' => 'Opcija za prilaganje PDFa na e-poštu klijenta',
    'resume' => 'Nastavi',
    'break_duration' => 'Prekini',
    'edit_details' => 'Izmeni detalje',
    'work' => 'Rad',
    'timezone_unset' => 'Molimo :link za podešavanje vaše vremenske zone',
    'click_here' => 'kliknite ovde',
    'email_receipt' => 'Pošalji e-poštom račun klijentu',
    'created_payment_emailed_client' => 'Uspešno kreirana uplata i poslata klijentu e-poštom',
    'add_company' => 'Dodaj preduzeće',
    'untitled' => 'Bez naslova',
    'new_company' => 'Novo preduzeće',
    'associated_accounts' => 'Uspešno povezani računi',
    'unlinked_account' => 'Uspešno razdvojeni računi',
    'login' => 'Prijava',
    'or' => 'ili',
    'email_error' => 'Došlo je do problema pri slanju e-pošte',
    'confirm_recurring_timing' => 'Beleška: e-pošta je poslata na početku sata.',
    'confirm_recurring_timing_not_sent' => 'Napomena: Računi se kreiraju početkom svakog sata',
    'payment_terms_help' => 'Podesi podrazumevani <b>datum dospeća računa</b>',
    'unlink_account' => 'Razdvoj naloge',
    'unlink' => 'Razdvoji',
    'show_address' => 'Prikaži adresu',
    'show_address_help' => 'Zahtevaj od klijenta adresu za fakture',
    'update_address' => 'Ažuriraj adresu',
    'update_address_help' => 'Ažuriraj adresu klijenta uz dostavljenim detaljima',
    'times' => 'Vremena',
    'set_now' => 'Postavi na sada',
    'dark_mode' => 'Tamni prikaz',
    'dark_mode_help' => 'Koristi tamnu pozadinu za menije',
    'add_to_invoice' => 'Dodaj računu :invoice',
    'create_new_invoice' => 'Kreiraj novi račun',
    'task_errors' => 'Molimo korigujte vremena koja se poklapaju',
    'from' => 'Šalje',
    'to' => 'Prima',
    'font_size' => 'Veličina fonta',
    'primary_color' => 'Primarna boja',
    'secondary_color' => 'Sekundarna boja',
    'customize_design' => 'Prilagodi dizajn',
    'content' => 'Sadržaj',
    'styles' => 'Stilovi',
    'defaults' => 'Podrazumevano',
    'margins' => 'Margine',
    'header' => 'Zaglavlje',
    'footer' => 'Podnožje',
    'custom' => 'Prilagođeno',
    'invoice_to' => 'Fakturiši na',
    'invoice_no' => 'Broj računa',
    'quote_no' => 'Predračun br.',
    'recent_payments' => 'Nedavne uplate',
    'outstanding' => 'Nenaplaćeno',
    'manage_companies' => 'Upravljanje preduzećima',
    'total_revenue' => 'Ukupni prihod',
    'current_user' => 'Trenutni korisnik',
    'new_recurring_invoice' => 'Novi ponavljajući račun',
    'recurring_invoice' => 'Ponavljajući račun',
    'new_recurring_quote' => 'Novi ponavljajuć predračun',
    'recurring_quote' => 'Ponavljajuća ponuda',
    'recurring_too_soon' => 'Prerano je za kreiranje novog redovnog računa, na rasporedu je za :date',
    'created_by_invoice' => 'Kreiran od :invoice',
    'primary_user' => 'Primarni korisnik',
    'help' => 'Pomoć',
    'customize_help' => '<p>Koristimo :pdfmake_link za deklarativno definisanje dezajna računa. Pdfmake :playground_link je dobar način da se vidi kako ova biblioteka funkcioniše.</p>
                        <p>Ukoliko Vam je potrebna pomoć, pošaljite pitanje na našem :forum_link, sa dizajnom koji koristite.</p>',
    'playground' => 'igralište',
    'support_forum' => 'forum podrške',
    'invoice_due_date' => 'Datum valute',
    'quote_due_date' => 'Vredi do',
    'valid_until' => 'Vredi do',
    'reset_terms' => 'Resetuj uslove',
    'reset_footer' => 'Resetuj podnožje',
    'invoice_sent' => ':count račun poslat',
    'invoices_sent' => ':count račun poslat',
    'status_draft' => 'Nacrt',
    'status_sent' => 'Poslato',
    'status_viewed' => 'Pregledano',
    'status_partial' => 'Delimično',
    'status_paid' => 'Plaćeno',
    'status_unpaid' => 'Neplaćeno',
    'status_all' => 'Sve',
    'show_line_item_tax' => 'Prikaži <b>poreze u liniji stavke</b>',
    'iframe_url' => 'Sajt',
    'iframe_url_help1' => 'Kopiraj sledeći kod na svoju web stranicu.',
    'iframe_url_help2' => 'Možete testirati mogućnost klikom na \'Pogledaj kao primalac\' za račun.',
    'auto_bill' => 'Auto naplata',
    'military_time' => '24 satno vreme',
    'last_sent' => 'Zadnje poslato',
    'reminder_emails' => 'E-pošta podsetnik',
    'quote_reminder_emails' => 'Email poruke podsetnika za predračune',
    'templates_and_reminders' => 'Šabloni & podsetnici',
    'subject' => 'Naslov',
    'body' => 'Telo',
    'first_reminder' => 'Prvi podsetnik',
    'second_reminder' => 'Drugi podsetnik',
    'third_reminder' => 'Treći podsetnik',
    'num_days_reminder' => 'Dana nakon isteka valute',
    'reminder_subject' => 'Podsetnik: Račun :invoice od :account',
    'reset' => 'Resetuj',
    'invoice_not_found' => 'Traženi račun nije dostupan',
    'referral_program' => 'Referentni progam',
    'referral_code' => 'Referentni URL',
    'last_sent_on' => 'Zadnje poslato :date',
    'page_expire' => 'Ova stranica će uskoro isteći, :click_here za nastavak rada',
    'upcoming_quotes' => 'Nadolazeći predračuni',
    'expired_quotes' => 'Istekli predračuni',
    'sign_up_using' => 'Prijavi se koristeći',
    'invalid_credentials' => 'Vaši podaci za prijavu ne odgovaraju našim podacima',
    'show_all_options' => 'Prikaži sve opcije',
    'user_details' => 'Detalji korisnika',
    'oneclick_login' => 'Povezani nalog',
    'disable' => 'Onemogući',
    'invoice_quote_number' => 'Brojevi računa i ponuda',
    'invoice_charges' => 'Dodatni troškovi na fakturi',
    'notification_invoice_bounced' => 'Nismo mogli dostaviti račun :invoice prema :contact.',
    'notification_invoice_bounced_subject' => 'Nije moguće dostaviti :invoice',
    'notification_quote_bounced' => 'Nismo mogli dostaviti predračun :invoice za :contact',
    'notification_quote_bounced_subject' => 'Nije moguće dostaviti predračun :invoice',
    'custom_invoice_link' => 'Prilagođen link računa',
    'total_invoiced' => 'Ukupno fakturisano',
    'open_balance' => 'Otvoreno stanje',
    'verify_email' => 'Molimo posetite link unutar potvrdne e-pošte računa kako bi potvrdili svoju adresu e-pošte.',
    'basic_settings' => 'Osnovna podešavanja',
    'pro' => 'Pro',
    'gateways' => 'Platni kanali',
    'next_send_on' => 'Pošalji sledeći: :date',
    'no_longer_running' => 'Ovaj račun nije zakazan za slanje',
    'general_settings' => 'Opšte postavke',
    'customize' => 'Prilagodi',
    'oneclick_login_help' => 'Spoji se na račun za prijavu bez lozinke',
    'referral_code_help' => 'Zaradite novac deleći našu aplikaciju online',
    'enable_with_stripe' => 'Omogući | Zahteva Stripe',
    'tax_settings' => 'Podešavanja poreza',
    'create_tax_rate' => 'Dodaj poresku stopu',
    'updated_tax_rate' => 'Uspešno ažurirana poreska stopa',
    'created_tax_rate' => 'Uspešno kreirana poreska stopa',
    'edit_tax_rate' => 'Uredi poresku stopu',
    'archive_tax_rate' => 'Arhiviraj poresku stopu',
    'archived_tax_rate' => 'Uspešno arhivirana poreska stopa',
    'default_tax_rate_id' => 'Zadata poreska stopa',
    'tax_rate' => 'Poreska stopa',
    'recurring_hour' => 'Ponavljajući sat',
    'pattern' => 'Uzorak',
    'pattern_help_title' => 'Pomoć za uzorke',
    'pattern_help_1' => 'Create custom numbers by specifying a pattern',
    'pattern_help_2' => 'Dostupne varijable:',
    'pattern_help_3' => 'Na primer, :example bi bilo pretvoreno u :value',
    'see_options' => 'Pogledaj opcije',
    'invoice_counter' => 'Brojač računa',
    'quote_counter' => 'Brojač predračuna',
    'type' => 'Tip',
    'activity_1' => ':user kreirao klijenta :client',
    'activity_2' => ':user arhivirao klijenta :client',
    'activity_3' => ':user obrisao klijenta :client',
    'activity_4' => ':user kreirao račun :invoice',
    'activity_5' => ':user ažurirao račun :invoice',
    'activity_6' => ':user je poslao račun :invoice za :client kontaktu :contact',
    'activity_7' => ':contact viewed invoice :invoice for :client',
    'activity_8' => ':user arhivirao račun :invoice',
    'activity_9' => ':user obrisao račun :invoce',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user ažurirao uplatu :payment',
    'activity_12' => ':user ahivirao uplatu :payment',
    'activity_13' => ':user obrisao uplatu :payment',
    'activity_14' => ':user upisao :credit kredit',
    'activity_15' => ':user ažurirao :credit kredit',
    'activity_16' => ':user arhivirao :credit kredit',
    'activity_17' => ':user obrisao :credit kredit',
    'activity_18' => ':user kreirao predračun :quote',
    'activity_19' => ':user ažurirao predračun :quote',
    'activity_20' => ':user emailed quote :quote for :client to :contact',
    'activity_21' => ':contact pregledao predračun :quote',
    'activity_22' => ':user arhivirao predračun :quote',
    'activity_23' => ':user obrisao predračun :quote',
    'activity_24' => ':user obnovio predračun :quote',
    'activity_25' => ':user obnovio račun :invoice',
    'activity_26' => ':user obnovio klijenta :client',
    'activity_27' => ':user obnovio uplatu :payment',
    'activity_28' => ':user obnovio :credit kredit',
    'activity_29' => ':contact approved quote :quote for :client',
    'activity_30' => ':user created vendor :vendor',
    'activity_31' => ':user archived vendor :vendor',
    'activity_32' => ':user deleted vendor :vendor',
    'activity_33' => ':user restored vendor :vendor',
    'activity_34' => ':user kreirao trošak :expense',
    'activity_35' => ':user archived expense :expense',
    'activity_36' => ':user deleted expense :expense',
    'activity_37' => ':user restored expense :expense',
    'activity_42' => ':user created task :task',
    'activity_43' => ':user updated task :task',
    'activity_44' => ':user archived task :task',
    'activity_45' => ':user deleted task :task',
    'activity_46' => ':user restored task :task',
    'activity_47' => ':user updated expense :expense',
    'activity_48' => ':user ažurirao tiket :ticket',
    'activity_49' => ':user zatvorio tiket :ticket',
    'activity_50' => ':user spojio tiket :ticket',
    'activity_51' => ':user podelio tiket :ticket',
    'activity_52' => ':contact otvorio tiket :ticket',
    'activity_53' => ':contact obnovio tiket :ticket',
    'activity_54' => ':user obnovio tiket :ticket',
    'activity_55' => ':contact odgovorio na tiket :ticket',
    'activity_56' => ':user pogledao tiket :ticket',

    'payment' => 'Uplata',
    'system' => 'Sistem',
    'signature' => 'Potpis e-pošte',
    'default_messages' => 'Podrazumevane poruke',
    'quote_terms' => 'Uslovi predračuna',
    'default_quote_terms' => 'Podrazumevani uslovi predračuna',
    'default_invoice_terms' => 'Podrazumevani uslovi računa',
    'default_invoice_footer' => 'Podrazumevano podnožje računa',
    'quote_footer' => 'Podnožje ponude',
    'free' => 'Slobodan',
    'quote_is_approved' => 'Uspešno potvrđeno',
    'apply_credit' => 'Primjeni kredit',
    'system_settings' => 'Podešavanja sistema',
    'archive_token' => 'Arhiviraj token',
    'archived_token' => 'Uspešno arhiviran token',
    'archive_user' => 'Arhiviraj korisnika',
    'archived_user' => 'Uspešno arhiviran korisnik',
    'archive_account_gateway' => 'Delete Gateway',
    'archived_account_gateway' => 'Uspešno arhiviran kanal',
    'archive_recurring_invoice' => 'Arhiviraj redovni račun',
    'archived_recurring_invoice' => 'Uspešno arhiviran redovni račun',
    'delete_recurring_invoice' => 'Obriši redovni račun',
    'deleted_recurring_invoice' => 'Uspešno obrisan redovni račun',
    'restore_recurring_invoice' => 'Obnovi redovni račun',
    'restored_recurring_invoice' => 'Uspešno obnovljen redovni račun',
    'archive_recurring_quote' => 'Arhiviraj ponavljajuću ponudu',
    'archived_recurring_quote' => 'uspešno arhivirana ponavljajuća ponuda',
    'delete_recurring_quote' => 'Obriši ponavljajuću ponudu',
    'deleted_recurring_quote' => 'Uspešno obrisana ponavljajuća ponuda',
    'restore_recurring_quote' => 'Obnovi ponavljajuću ponudu',
    'restored_recurring_quote' => 'Uspešno odnovljena ponavljajuća ponuda',
    'archived' => 'Arhivirano',
    'untitled_account' => 'Neimenovano preduzeće',
    'before' => 'Prije',
    'after' => 'Poslije',
    'reset_terms_help' => 'Resetuj na podrazumevana podešavanja računa',
    'reset_footer_help' => 'Resetuj na podrazumevana podešavanja podnožja',
    'export_data' => 'Izvezi podatke',
    'user' => 'Korisnik',
    'country' => 'Zemlja',
    'include' => 'Uključi',
    'logo_too_large' => 'Vaš logo je :size, za bolju PDF izvedbu preporučujemo korišćenje slike manje od 200KB',
    'import_freshbooks' => 'Uvezi iz FreshBooks',
    'import_data' => 'Uvezi podatke',
    'source' => 'Izvor',
    'csv' => 'CSV',
    'client_file' => 'Klijentska datoteka',
    'invoice_file' => 'Datoteka računa',
    'task_file' => 'Datoteka zadataka',
    'no_mapper' => 'Nema ispravnog mapiranja za datoteku',
    'invalid_csv_header' => 'Neispravno CSV zaglavlje',
    'client_portal' => 'Klijentski portal',
    'admin' => 'Administracija',
    'disabled' => 'Onemogućeno',
    'show_archived_users' => 'Prikaži arhivirane korisnike',
    'notes' => 'Beleške',
    'invoice_will_create' => 'račun će biti kreiran',
    'invoices_will_create' => 'računi će biti kreirani',
    'failed_to_import' => 'The following records failed to import, they either already exist or are missing required fields.',
    'publishable_key' => 'Ključ za objavljivanje',
    'secret_key' => 'Tajni ključ',
    'missing_publishable_key' => 'Postavite vaš Stripe javni ključ za poboljšani proces odjave',
    'email_design' => 'Dizajn e-pošte',
    'due_by' => 'Valuta do :date',
    'enable_email_markup' => 'Omogući markup',
    'enable_email_markup_help' => 'Olakšajte svojim klijentima plaćanje dodavanjem schema.org markupa vašoj e-pošti.',
    'template_help_title' => 'Pomoć za predloške',
    'template_help_1' => 'Dostupne varijable:',
    'email_design_id' => 'Stil e-pošte',
    'email_design_help' => 'Make your emails look more professional with HTML layouts.',
    'plain' => 'Obično',
    'light' => 'Svetlo',
    'dark' => 'Tamno',
    'industry_help' => 'Koristi se za poređenje između proseka preduzeća sličnih veličina i delatnosti.',
    'subdomain_help' => 'Set the subdomain or display the invoice on your own website.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Odredite prefiks ili koristite prilagođeni uzorak za dinamičko postavljanje brojeva računa.',
    'quote_number_help' => 'Odredite prefiks ili koristite prilagođeni uzorak za dinamičko postavljanje brojeva ponuda.',
    'custom_client_fields_helps' => 'Dodajte polje kada kreirate klijenta i opciono prikažite oznaku i vrednost na PDF-u.',
    'custom_account_fields_helps' => 'Dodajte oznaku i vrednost na sekciju sa detaljima preduzeća na PDFu.',
    'custom_invoice_fields_helps' => 'Dodajte polje kada kreirate račun i opciono prikažite oznaku i vrednost na PDF-u.',
    'custom_invoice_charges_helps' => 'Add a field when creating an invoice and include the charge in the invoice subtotals.',
    'token_expired' => 'Token je istekao. Molimo pokušajte ponovo.',
    'invoice_link' => 'Link računa',
    'button_confirmation_message' => 'Kliknite za potvrdu vaše adrese e-pošte.',
    'confirm' => 'Odobri',
    'email_preferences' => 'Podešavanja e-pošte',
    'created_invoices' => 'Uspešno kreirano :count računa',
    'next_invoice_number' => 'Sledeći broj računa je :number.',
    'next_quote_number' => 'Sledeći broj ponude je :number.',
    'days_before' => 'days before the',
    'days_after' => 'days after the',
    'field_due_date' => 'datum valute',
    'field_invoice_date' => 'datum računa',
    'schedule' => 'Raspored',
    'email_designs' => 'Dizajn e-pošte',
    'assigned_when_sent' => 'Dodeljeno pri slanju',
    'white_label_purchase_link' => 'Kupite licencu bele oznake',
    'expense' => 'Trošak',
    'expenses' => 'Troškovi',
    'new_expense' => 'Unesi trošak',
    'enter_expense' => 'Unesi trošak',
    'vendors' => 'Dobavljači',
    'new_vendor' => 'Novi dobavljač',
    'payment_terms_net' => 'čisto',
    'vendor' => 'Dobavljač',
    'edit_vendor' => 'Uredi dobavljača',
    'archive_vendor' => 'Arhiviraj dobavljača',
    'delete_vendor' => 'Obriši dobavljača',
    'view_vendor' => 'Pregledaj dobavljača',
    'deleted_expense' => 'Uspešno obrisan trošak',
    'archived_expense' => 'Uspešno arhiviran trošak',
    'deleted_expenses' => 'Uspešno obrisan trošak',
    'archived_expenses' => 'Uspešno arhivirani troškovi',
    'expense_amount' => 'Iznos troškova',
    'expense_balance' => 'Stanje troškova',
    'expense_date' => 'Datum troška',
    'expense_should_be_invoiced' => 'Treba li fakturisati ovaj trošak?',
    'public_notes' => 'Javne beleške',
    'invoice_amount' => 'Iznos računa',
    'exchange_rate' => 'Kurs',
    'yes' => 'Da',
    'no' => 'Ne',
    'should_be_invoiced' => 'Treba biti fakturisan',
    'view_expense' => 'Pregled troškova # :expense',
    'edit_expense' => 'Izmeni trošak',
    'archive_expense' => 'Arhiviraj trošak',
    'delete_expense' => 'Obriši trošak',
    'view_expense_num' => 'Trošak # :expense',
    'updated_expense' => 'Uspešno ažuriran trošak',
    'created_expense' => 'Uspešno kreiran trošak',
    'enter_expense' => 'Unesi trošak',
    'view' => 'Pregled',
    'restore_expense' => 'Obnovi trošak',
    'invoice_expense' => 'Trošak računa',
    'expense_error_multiple_clients' => 'Troškovi ne mogu pripadati različitim klijentima',
    'expense_error_invoiced' => 'Trošak je već fakturisan',
    'convert_currency' => 'Konvertuj valutu',
    'num_days' => 'Number of Days',
    'create_payment_term' => 'Kreiraj uslove plaćanja',
    'edit_payment_terms' => 'Uredi uslov plaćanja',
    'edit_payment_term' => 'Uredi uslove plaćanja',
    'archive_payment_term' => 'Arhiviraj uslov plaćanja',
    'recurring_due_dates' => 'Datumi dospeća redovnih računa',
    'recurring_due_date_help' => '<p>Automatski postavlja datume dospeća za račune.</p>
        <p>Računi unutar mesečnog ili godišnjeg ciklusa postavljeni da dospevaju na dan ili pre dana na koji su kreirani biće dospeli sledeći mesec. Računi postavljeni da dospevaju na 29. ili 30. u mesecu a koji nemaju taj dan biće dospeli zadnji dan u mesecu.</p>
        <p>Računi unutar nedeljnog ciklusa postavljeni da dospevaju na dan u nedelji kada su kreirani dospevaće sledeće nedelje.</p>
        <p>Na primer:</p>
        <ul>
          <li>Danas je 15., datum dospeća je 1. u mesecu. Datum dospeća je 1. sledećeg meseca.</li>
          <li>Danas je 15., datum dospeća je zadnji dan u mesecu. Datum dospeća je poslednji dan u ovom mesecu.
</li>
          <li>Danas je 15, datum dospeća je 15. u mesecu. Datum dospeća će biti 15 dan  <strong>sledećeg</strong> meseca.
</li>
          <li>Danas je petak, datum dospeća je prvi sledeći petak. Datum dospeća je prvi sledeći petak, a ne današnji petak.
</li>
        </ul>',
    'due' => 'Dospelo',
    'next_due_on' => 'Dospeva sledeće :date',
    'use_client_terms' => 'Koristi uslove klijenta',
    'day_of_month' => ':ordinal dan u mesecu',
    'last_day_of_month' => 'Poslednji dan u mesecu',
    'day_of_week_after' => ':ordinal :day nakon',
    'sunday' => 'Nedelja',
    'monday' => 'Ponedeljak',
    'tuesday' => 'Utorak',
    'wednesday' => 'Sreda',
    'thursday' => 'Četvrtak',
    'friday' => 'Petak',
    'saturday' => 'Subota',
    'header_font_id' => 'Font zaglavlja',
    'body_font_id' => 'Font tela',
    'color_font_help' => 'Beleška: primarna boja i fontovi su takođe korišćeni u klijentskom portalu i prilagođenom dizajnu e-pošte',
    'live_preview' => 'Pregled uživo',
    'invalid_mail_config' => 'Nije moguće poslati e-poštu, molim proverite da li su vaša podešavanja e-pošte ispravna.',
    'invoice_message_button' => 'Za pregled vašeg račun iznosa :amount, kliknite na dugme ispod.',
    'quote_message_button' => 'Za pregled vaše ponude iznosa :amount, kliknite dugme ispod.',
    'payment_message_button' => 'Hvala vam na vašoj uplati od :amount.',
    'payment_type_direct_debit' => 'Direktni dug',
    'bank_accounts' => 'Kreditne kartice & banke',
    'add_bank_account' => 'Dodajte bankovni račun',
    'setup_account' => 'Podešavanja računa',
    'import_expenses' => 'Uvezi troškove',
    'bank_id' => 'Bank',
    'integration_type' => 'Tip integracije',
    'updated_bank_account' => 'Uspešno ažuriran bankovni račun',
    'edit_bank_account' => 'Uredi bankovni račun',
    'archive_bank_account' => 'Arhiviraj bankovni račun',
    'archived_bank_account' => 'Uspešno arhiviran bankovni račun',
    'created_bank_account' => 'Uspešno kreiran bankovni račun',
    'validate_bank_account' => 'Proveri bankovni račun',
    'bank_password_help' => 'Beleška: vaša lozinka je sigurno poslata i nikada nije čuvana na našim serverima.',
    'bank_password_warning' => 'Pažnja: vaša lozinka je mogla biti poslata  kao običan tekst, razmotrite omogućavanje HTTPSa.',
    'username' => 'Korisničko ime',
    'account_number' => 'Broj računa',
    'account_name' => 'Ime računa',
    'bank_account_error' => 'Neuspešno prikupljanje detalja računa, molimo Vas da proverite korisničko ime i lozinku.',
    'status_approved' => 'Odobreno',
    'quote_settings' => 'Podešavanja ponude',
    'auto_convert_quote' => 'Auto konverzija',
    'auto_convert_quote_help' => 'Automatski konvertujte ponudu u račun nakon što je odobrena od strane klijenta.',
    'validate' => 'Validiraj',
    'info' => 'Info',
    'imported_expenses' => 'Uspešno kreirano :count_vendors dobavljača i :count_expenses troškova',
    'iframe_url_help3' => 'Beleška: Ukoliko planirate prihvatati kreditne kartice, preporučujemo omogućavanje HTTPS na vašoj web stranici.',
    'expense_error_multiple_currencies' => 'Troškovi ne mogu imati različite valute.',
    'expense_error_mismatch_currencies' => 'Valute klijenata se ne podudaraju sa valutama troškova.',
    'trello_roadmap' => 'Trello roadmap',
    'header_footer' => 'Zaglavlje/Podnožje',
    'first_page' => 'First page',
    'all_pages' => 'All pages',
    'last_page' => 'Last page',
    'all_pages_header' => 'Prikaži zaglavlje na',
    'all_pages_footer' => 'Prikaži podnožje na',
    'invoice_currency' => 'Valuta računa',
    'enable_https' => 'Preporučujemo korišćenje HTTPS za preuzimanje detalja kreditnih kartica online.',
    'quote_issued_to' => 'Ponuda napravljena za',
    'show_currency_code' => 'Kod valute',
    'free_year_message' => 'Vaš nalog je nadograđen u pro plan u trajanju od jedne godine bez troškova.',
    'trial_message' => 'Vaš račun će primiti besplatni dvonedeljni probni rok za naš pro plan.',
    'trial_footer' => 'Vaš besplatni  pro plan traje još :count dana, :link kliknite za upgrade.',
    'trial_footer_last_day' => 'Ovo je zadnji dan vašeg probnog roka, :link za trenutnu nadogradnju.',
    'trial_call_to_action' => 'Pokreni besplatni probni rok',
    'trial_success' => 'Uspešno je omogućeno dve nedelje besplatnog probnog pro plan roka',
    'overdue' => 'Van valute',


    'white_label_text' => 'Purchase a ONE YEAR white label license for $:price to remove the Invoice Ninja branding from the invoice and client portal.',
    'user_email_footer' => 'To adjust your email notification settings please visit :link',
    'reset_password_footer' => 'If you did not request this password reset please email our support: :email',
    'limit_users' => 'Sorry, this will exceed the limit of :limit users',
    'more_designs_self_host_header' => 'Get 6 more invoice designs for just $:price',
    'old_browser' => 'Molimo koristite  :link',
    'newer_browser' => 'noviji preglednik',
    'white_label_custom_css' => ':link for $:price to enable custom styling and help support our project.',
    'bank_accounts_help' => 'Povežite bankovni nalog za automatski uvoz troškova i kreiranje dobavljača. Podržava American Express i :link.',
    'us_banks' => '400+ US banaka',

    'pro_plan_remove_logo' => ':link to remove the Invoice Ninja logo by joining the Pro Plan',
    'pro_plan_remove_logo_link' => 'Click here',
    'invitation_status_sent' => 'Poslato',
    'invitation_status_opened' => 'Otvoreno',
    'invitation_status_viewed' => 'Viewed',
    'email_error_inactive_client' => 'Emails can not be sent to inactive clients',
    'email_error_inactive_contact' => 'Emails can not be sent to inactive contacts',
    'email_error_inactive_invoice' => 'Emails can not be sent to inactive invoices',
    'email_error_inactive_proposal' => 'e-pošta se ne može poslati za neaktivnu ponudu',
    'email_error_user_unregistered' => 'Please register your account to send emails',
    'email_error_user_unconfirmed' => 'Please confirm your account to send emails',
    'email_error_invalid_contact_email' => 'Invalid contact email',

    'navigation' => 'Navigation',
    'list_invoices' => 'List Invoices',
    'list_clients' => 'List Clients',
    'list_quotes' => 'List Quotes',
    'list_tasks' => 'List Tasks',
    'list_expenses' => 'List Expenses',
    'list_recurring_invoices' => 'List Recurring Invoices',
    'list_payments' => 'List Payments',
    'list_credits' => 'List Credits',
    'tax_name' => 'Naziv poreske stope',
    'report_settings' => 'Report Settings',
    'search_hotkey' => 'shortcut is /',

    'new_user' => 'New User',
    'new_product' => 'New Product',
    'new_tax_rate' => 'New Tax Rate',
    'invoiced_amount' => 'Iznos računa',
    'invoice_item_fields' => 'Invoice Item Fields',
    'custom_invoice_item_fields_help' => 'Add a field when creating an invoice item and display the label and value on the PDF.',
    'recurring_invoice_number' => 'Recurring Number',
    'recurring_invoice_number_prefix_help' => 'Specify a prefix to be added to the invoice number for recurring invoices.',

    // Client Passwords
    'enable_portal_password' => 'Password Protect Invoices',
    'enable_portal_password_help' => 'Allows you to set a password for each contact. If a password is set, the contact will be required to enter a password before viewing invoices.',
    'send_portal_password' => 'Generiši automatski',
    'send_portal_password_help' => 'If no password is set, one will be generated and sent with the first invoice.',

    'expired' => 'Expired',
    'invalid_card_number' => 'The credit card number is not valid.',
    'invalid_expiry' => 'The expiration date is not valid.',
    'invalid_cvv' => 'The CVV is not valid.',
    'cost' => 'Cost',
    'create_invoice_for_sample' => 'Note: create your first invoice to see a preview here.',

    // User Permissions
    'owner' => 'Owner',
    'administrator' => 'Administrator',
    'administrator_help' => 'Allow user to manage users, change settings and modify all records',
    'user_create_all' => 'Create clients, invoices, etc.',
    'user_view_all' => 'View all clients, invoices, etc.',
    'user_edit_all' => 'Edit all clients, invoices, etc.',
    'gateway_help_20' => ':link to sign up for Sage Pay.',
    'gateway_help_21' => ':link to sign up for Sage Pay.',
    'partial_due' => 'Partial Due',
    'restore_vendor' => 'Restore Vendor',
    'restored_vendor' => 'Successfully restored vendor',
    'restored_expense' => 'Successfully restored expense',
    'permissions' => 'Permissions',
    'create_all_help' => 'Allow user to create and modify records',
    'view_all_help' => 'Allow user to view records they didn\'t create',
    'edit_all_help' => 'Allow user to modify records they didn\'t create',
    'view_payment' => 'View Payment',

    'january' => 'January',
    'february' => 'February',
    'march' => 'March',
    'april' => 'April',
    'may' => 'May',
    'june' => 'June',
    'july' => 'July',
    'august' => 'August',
    'september' => 'September',
    'october' => 'October',
    'november' => 'November',
    'december' => 'December',

    // Documents
    'documents_header' => 'Dokumenti:',
    'email_documents_header' => 'Dokumenti:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Dokumenti ponude',
    'invoice_documents' => 'Dokumenti računa',
    'expense_documents' => 'Dokumenti troškova',
    'invoice_embed_documents' => 'Embed Documents',
    'invoice_embed_documents_help' => 'Include attached images in the invoice.',
    'document_email_attachment' => 'Attach Documents',
    'ubl_email_attachment' => 'Dodaj UBL',
    'download_documents' => 'Download Documents (:size)',
    'documents_from_expenses' => 'From Expenses:',
    'dropzone_default_message' => 'Drop files or click to upload',
    'dropzone_default_message_disabled' => 'Slanje fajlova nije omogućeno',
    'dropzone_fallback_message' => 'Your browser does not support drag\'n\'drop file uploads.',
    'dropzone_fallback_text' => 'Please use the fallback form below to upload your files like in the olden days.',
    'dropzone_file_too_big' => 'File is too big ({{filesize}}MiB). Max filesize: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'You can\'t upload files of this type.',
    'dropzone_response_error' => 'Server responded with {{statusCode}} code.',
    'dropzone_cancel_upload' => 'Cancel upload',
    'dropzone_cancel_upload_confirmation' => 'Are you sure you want to cancel this upload?',
    'dropzone_remove_file' => 'Remove file',
    'documents' => 'Dokumenti',
    'document_date' => 'Document Date',
    'document_size' => 'Size',

    'enable_client_portal' => 'Client Portal',
    'enable_client_portal_help' => 'Show/hide the client portal.',
    'enable_client_portal_dashboard' => 'Dashboard',
    'enable_client_portal_dashboard_help' => 'Show/hide the dashboard page in the client portal.',

    // Plans
    'account_management' => 'Account Management',
    'plan_status' => 'Plan Status',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Change Plan',
    'pending_change_to' => 'Changes To',
    'plan_changes_to' => ':plan on :date',
    'plan_term_changes_to' => ':plan (:term) on :date',
    'cancel_plan_change' => 'Cancel Change',
    'plan' => 'Plan',
    'expires' => 'Expires',
    'renews' => 'Renews',
    'plan_expired' => ':plan Plan Expired',
    'trial_expired' => ':plan Plan Trial Ended',
    'never' => 'Nikada',
    'plan_free' => 'Free',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'Trial',
    'plan_term' => 'Term',
    'plan_term_monthly' => 'Mesečno',
    'plan_term_yearly' => 'Godišnje',
    'plan_term_month' => 'Mesec',
    'plan_term_year' => 'Godina',
    'plan_price_monthly' => '$:price/Month',
    'plan_price_yearly' => '$:price/Year',
    'updated_plan' => 'Updated plan settings',
    'plan_paid' => 'Term Started',
    'plan_started' => 'Plan Started',
    'plan_expires' => 'Plan Expires',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'One year enrollment in the Invoice Ninja Pro Plan.',
    'pro_plan_month_description' => 'One month enrollment in the Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'One year enrollment in the Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'One month enrollment in the Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'Credit',
    'plan_credit_description' => 'Credit for unused time',
    'plan_pending_monthly' => 'Will switch to monthly on :date',
    'plan_refunded' => 'A refund has been issued.',

    'live_preview' => 'Pregled uživo',
    'page_size' => 'Page Size',
    'live_preview_disabled' => 'Live preview has been disabled to support selected font',
    'invoice_number_padding' => 'Padding',
    'preview' => 'Preview',
    'list_vendors' => 'List Vendors',
    'add_users_not_supported' => 'Upgrade to the Enterprise plan to add additional users to your account.',
    'enterprise_plan_features' => 'The Enterprise plan adds support for multiple users and file attachments, :link to see the full list of features.',
    'return_to_app' => 'Povratak u apliakciju',


    // Payment updates
    'refund_payment' => 'Refund Payment',
    'refund_max' => 'Max:',
    'refund' => 'Refund',
    'are_you_sure_refund' => 'Refund selected payments?',
    'status_pending' => 'Pending',
    'status_completed' => 'Completed',
    'status_failed' => 'Failed',
    'status_partially_refunded' => 'Partially Refunded',
    'status_partially_refunded_amount' => ':amount Refunded',
    'status_refunded' => 'Refunded',
    'status_voided' => 'Cancelled',
    'refunded_payment' => 'Refunded Payment',
    'activity_39' => ':user je otkazao :payment_amount plaćanje :payment',
    'activity_40' => ':user vratio :adjustment od :payment_amount plaćanja :payment',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Unknown',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Prihvati transfer US banke',
    'stripe_ach_help' => 'Podrška za ACH mora biti omogućena na :link.',
    'ach_disabled' => 'Another gateway is already configured for direct debit.',

    'plaid' => 'Plaid',
    'client_id' => 'Client Id',
    'secret' => 'Secret',
    'public_key' => 'Javni ključ',
    'plaid_optional' => '(optional)',
    'plaid_environment_help' => 'Kada se unese Stripe test kjluč, koristiće se Plaid-ovo razvojno okruženje (tartan).
',
    'other_providers' => 'Other Providers',
    'country_not_supported' => 'That country is not supported.',
    'invalid_routing_number' => 'The routing number is not valid.',
    'invalid_account_number' => 'The account number is not valid.',
    'account_number_mismatch' => 'The account numbers do not match.',
    'missing_account_holder_type' => 'Please select an individual or company account.',
    'missing_account_holder_name' => 'Please enter the account holder\'s name.',
    'routing_number' => 'Routing Number',
    'confirm_account_number' => 'Confirm Account Number',
    'individual_account' => 'Individual Account',
    'company_account' => 'Company Account',
    'account_holder_name' => 'Account Holder Name',
    'add_account' => 'Add Account',
    'payment_methods' => 'Payment Methods',
    'complete_verification' => 'Complete Verification',
    'verification_amount1' => 'Amount 1',
    'verification_amount2' => 'Amount 2',
    'payment_method_verified' => 'Verification completed successfully',
    'verification_failed' => 'Verification Failed',
    'remove_payment_method' => 'Remove Payment Method',
    'confirm_remove_payment_method' => 'Are you sure you want to remove this payment method?',
    'remove' => 'Remove',
    'payment_method_removed' => 'Removed payment method.',
    'bank_account_verification_help' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement. Please enter the amounts below.',
    'bank_account_verification_next_steps' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement.
        Once you have the amounts, come back to this payment methods page and click "Complete Verification" next to the account.',
    'unknown_bank' => 'Unknown Bank',
    'ach_verification_delay_help' => 'You will be able to use the account after completing verification. Verification usually takes 1-2 business days.',
    'add_credit_card' => 'Add Credit Card',
    'payment_method_added' => 'Added payment method.',
    'use_for_auto_bill' => 'Use For Autobill',
    'used_for_auto_bill' => 'Autobill Payment Method',
    'payment_method_set_as_default' => 'Set Autobill payment method.',
    'activity_41' => ':payment_amount payment (:payment) failed',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'You must :link.',
    'stripe_webhook_help_link_text' => 'add this URL as an endpoint at Stripe',
    'gocardless_webhook_help_link_text' => 'dodaj ovaj URL kao pristupnu tačku za GoCardless',
    'payment_method_error' => 'There was an error adding your payment methd. Please try again later.',
    'notification_invoice_payment_failed_subject' => 'Payment failed for Invoice :invoice',
    'notification_invoice_payment_failed' => 'A payment made by client :client towards Invoice :invoice failed. The payment has been marked as failed and :amount has been added to the client\'s balance.',
    'link_with_plaid' => 'Link Account Instantly with Plaid',
    'link_manually' => 'Link Manually',
    'secured_by_plaid' => 'Secured by Plaid',
    'plaid_linked_status' => 'Your bank account at :bank',
    'add_payment_method' => 'Add Payment Method',
    'account_holder_type' => 'Account Holder Type',
    'ach_authorization' => 'I authorize :company to use my bank account for future payments and, if necessary, electronically credit my account to correct erroneous debits. I understand that I may cancel this authorization at any time by removing the payment method or by contacting :email.',
    'ach_authorization_required' => 'You must consent to ACH transactions.',
    'off' => 'Off',
    'opt_in' => 'Opt-in',
    'opt_out' => 'Opt-out',
    'always' => 'Always',
    'opted_out' => 'Opted out',
    'opted_in' => 'Opted in',
    'manage_auto_bill' => 'Manage Auto-bill',
    'enabled' => 'Enabled',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Enable PayPal payments through BrainTree',
    'braintree_paypal_disabled_help' => 'The PayPal gateway is processing PayPal payments',
    'braintree_paypal_help' => 'You must also :link.',
    'braintree_paypal_help_link_text' => 'link PayPal to your BrainTree account',
    'token_billing_braintree_paypal' => 'Save payment details',
    'add_paypal_account' => 'Add PayPal Account',


    'no_payment_method_specified' => 'No payment method specified',
    'chart_type' => 'Chart Type',
    'format' => 'Format',
    'import_ofx' => 'Import OFX',
    'ofx_file' => 'OFX File',
    'ofx_parse_failed' => 'Failed to parse OFX file',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Sign up with WePay',
    'use_another_provider' => 'Use another provider',
    'company_name' => 'Company Name',
    'wepay_company_name_help' => 'This will appear on client\'s credit card statements.',
    'wepay_description_help' => 'The purpose of this account.',
    'wepay_tos_agree' => 'I agree to the :link.',
    'wepay_tos_link_text' => 'WePay Terms of Service',
    'resend_confirmation_email' => 'Resend Confirmation Email',
    'manage_account' => 'Manage Account',
    'action_required' => 'Action Required',
    'finish_setup' => 'Finish Setup',
    'created_wepay_confirmation_required' => 'Please check your email and confirm your email address with WePay.',
    'switch_to_wepay' => 'Switch to WePay',
    'switch' => 'Switch',
    'restore_account_gateway' => 'Povrati kanal',
    'restored_account_gateway' => 'Uspešno povraćen kanal',
    'united_states' => 'United States',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Accept Debit Cards',
    'debit_cards' => 'Debit Cards',

    'warn_start_date_changed' => 'The next invoice will be sent on the new start date.',
    'warn_start_date_changed_not_sent' => 'Sledeći račun će biti kreiran na novi početni datum.',
    'original_start_date' => 'Original start date',
    'new_start_date' => 'New start date',
    'security' => 'Security',
    'see_whats_new' => 'See what\'s new in v:version',
    'wait_for_upload' => 'Please wait for the document upload to complete.',
    'upgrade_for_permissions' => 'Upgrade to our Enterprise plan to enable permissions.',
    'enable_second_tax_rate' => 'Enable specifying a <b>second tax rate</b>',
    'payment_file' => 'Payment File',
    'expense_file' => 'Expense File',
    'product_file' => 'Product File',
    'import_products' => 'Import Products',
    'products_will_create' => 'Proizvod će biti kreiran',
    'product_key' => 'Product',
    'created_products' => 'Uspešno kreirano/izmenjeno  :count proizvod(a)',
    'export_help' => 'Use JSON if you plan to import the data into Invoice Ninja.<br/>The file includes clients, products, invoices, quotes and payments.',
    'selfhost_export_help' => '<br/>Preporučujemo upotrebu mysqldump za kreiranje sigurnosne kopije.',
    'JSON_file' => 'JSON File',

    'view_dashboard' => 'View Dashboard',
    'client_session_expired' => 'Session Expired',
    'client_session_expired_message' => 'Your session has expired. Please click the link in your email again.',

    'auto_bill_notification' => 'This invoice will automatically be billed to your :payment_method on file on :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'bank account',
    'auto_bill_payment_method_credit_card' => 'credit card',
    'auto_bill_payment_method_paypal' => 'PayPal account',
    'auto_bill_notification_placeholder' => 'This invoice will automatically be billed to your credit card on file on the due date.',
    'payment_settings' => 'Payment Settings',

    'on_send_date' => 'On send date',
    'on_due_date' => 'On due date',
    'auto_bill_ach_date_help' => 'ACH will always auto bill on the due date.',
    'warn_change_auto_bill' => 'Due to NACHA rules, changes to this invoice may prevent ACH auto bill.',

    'bank_account' => 'Bank Account',
    'payment_processed_through_wepay' => 'ACH payments will be processed using WePay.',
    'wepay_payment_tos_agree' => 'I agree to the WePay :terms and :privacy_policy.',
    'privacy_policy' => 'Privacy Policy',
    'wepay_payment_tos_agree_required' => 'You must agree to the WePay Terms of Service and Privacy Policy.',
    'ach_email_prompt' => 'Please enter your email address:',
    'verification_pending' => 'Verification Pending',

    'update_font_cache' => 'Please force refresh the page to update the font cache.',
    'more_options' => 'More options',
    'credit_card' => 'Credit Card',
    'bank_transfer' => 'Bank Transfer',
    'no_transaction_reference' => 'We did not recieve a payment transaction reference from the gateway.',
    'use_bank_on_file' => 'Use Bank on File',
    'auto_bill_email_message' => 'This invoice will automatically be billed to the payment method on file on the due date.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Added :date',
    'failed_remove_payment_method' => 'Failed to remove the payment method',
    'gateway_exists' => 'Ovaj kanal već postoji',
    'manual_entry' => 'Manual entry',
    'start_of_week' => 'First Day of the Week',

    // Frequencies
    'freq_inactive' => 'Neaktivno',
    'freq_daily' => 'Svakodnevno',
    'freq_weekly' => 'Weekly',
    'freq_biweekly' => 'Dva puta nedeljno',
    'freq_two_weeks' => 'Two weeks',
    'freq_four_weeks' => 'Four weeks',
    'freq_monthly' => 'Monthly',
    'freq_three_months' => 'Three months',
    'freq_four_months' => 'Četiri meseca',
    'freq_six_months' => 'Six months',
    'freq_annually' => 'Annually',
    'freq_two_years' => 'Dve godine',

    // Payment types
    'payment_type_Apply Credit' => 'Apply Credit',
    'payment_type_Bank Transfer' => 'Bank Transfer',
    'payment_type_Cash' => 'Cash',
    'payment_type_Debit' => 'Debit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Card',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Credit Card Other',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Check',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direktno Zaduženje',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Accounting & Legal',
    'industry_Advertising' => 'Advertising',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automotive',
    'industry_Banking & Finance' => 'Banking & Finance',
    'industry_Biotechnology' => 'Biotechnology',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Defense',
    'industry_Energy' => 'Energija',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Government',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Insurance',
    'industry_Manufacturing' => 'Proizvodnja',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Pharmaceuticals',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Nekretnine',
    'industry_Restaurant & Catering' => 'Restorani & Ketering',
    'industry_Retail & Wholesale' => 'Retail & Wholesale',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Travel & Luxury',
    'industry_Other' => 'Drugo',
    'industry_Photography' => 'Photography',

    // Countries
    'country_Afghanistan' => 'Avghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andora',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australija',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgija',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosna i Hercegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bugarska',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Kamerun',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Šri Lanka',
    'country_Chad' => 'Čad',
    'country_Chile' => 'Čile',
    'country_China' => 'Kina',
    'country_Taiwan, Province of China' => 'Taiwan, Province of China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Kongo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croatia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cyprus',
    'country_Czech Republic' => 'Czech Republic',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Denmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Etijopija',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonija',
    'country_Faroe Islands' => 'Farska Ostrva',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'France',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germany',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Grčka',
    'country_Greenland' => 'Greenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Mađarska',
    'country_Iceland' => 'Iceland',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonezija',
    'country_Iran, Islamic Republic of' => 'Iran, Islamic Republic of',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Ireland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italy',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenija',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Liban',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libija',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuania',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Meksiko',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Crna Gora',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Holandija',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norway',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Poland',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Rumunija',
    'country_Russian Federation' => 'Ruska federacija',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Srbija',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spain',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sweden',
    'country_Switzerland' => 'Switzerland',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turska',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'United Kingdom',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'United States',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Urugvaj',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazilian Portuguese',
    'lang_Croatian' => 'Hrvatski',
    'lang_Czech' => 'Češki',
    'lang_Danish' => 'Danski',
    'lang_Dutch' => 'Holandski',
    'lang_English' => 'Engleski',
    'lang_French' => 'Francuski',
    'lang_French - Canada' => 'French - Canada',
    'lang_German' => 'Nemački',
    'lang_Italian' => 'Italijanski',
    'lang_Japanese' => 'Japanese',
    'lang_Lithuanian' => 'Lithuanian',
    'lang_Norwegian' => 'Norveški',
    'lang_Polish' => 'Poljski',
    'lang_Spanish' => 'Španski',
    'lang_Spanish - Spain' => 'Spanish - Spain',
    'lang_Swedish' => 'Švedski',
    'lang_Albanian' => 'Albanian',
    'lang_Greek' => 'Grčki',
    'lang_English - United Kingdom' => 'English - United Kingdom',
    'lang_English - Australia' => 'Engleski - Australija',
    'lang_Slovenian' => 'Slovenian',
    'lang_Finnish' => 'Finski',
    'lang_Romanian' => 'Rumunski',
    'lang_Turkish - Turkey' => 'Turski - Turska',
    'lang_Portuguese - Brazilian' => 'Portugalski - Brazil',
    'lang_Portuguese - Portugal' => 'Portugalski - Portugalija',
    'lang_Thai' => 'Tajlandski',
    'lang_Macedonian' => 'Makedonski',
    'lang_Chinese - Taiwan' => 'Kineski - Tajvan',
    'lang_Serbian' => 'Srpski',
    'lang_Bulgarian' => 'Bugarski',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Accounting & Legal',
    'industry_Advertising' => 'Advertising',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automotive',
    'industry_Banking & Finance' => 'Banking & Finance',
    'industry_Biotechnology' => 'Biotechnology',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Defense',
    'industry_Energy' => 'Energija',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Government',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Insurance',
    'industry_Manufacturing' => 'Proizvodnja',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Pharmaceuticals',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Nekretnine',
    'industry_Retail & Wholesale' => 'Retail & Wholesale',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Travel & Luxury',
    'industry_Other' => 'Drugo',
    'industry_Photography' => 'Photography',

    'view_client_portal' => 'View client portal',
    'view_portal' => 'Pogledaj portal',
    'vendor_contacts' => 'Kontakti dobavljača',
    'all' => 'All',
    'selected' => 'Selected',
    'category' => 'Category',
    'categories' => 'Categories',
    'new_expense_category' => 'Nova kategorija troškova',
    'edit_category' => 'Izmeni kategoriju',
    'archive_expense_category' => 'Arhiviraj kategoriju',
    'expense_categories' => 'Expense Categories',
    'list_expense_categories' => 'List Expense Categories',
    'updated_expense_category' => 'Successfully updated expense category',
    'created_expense_category' => 'Successfully created expense category',
    'archived_expense_category' => 'Successfully archived expense category',
    'archived_expense_categories' => 'Successfully archived :count expense category',
    'restore_expense_category' => 'Vrati kategoriju troškova',
    'restored_expense_category' => 'Uspešno vraćena kategorija troškova',
    'apply_taxes' => 'Apply taxes',
    'min_to_max_users' => ':min to :max users',
    'max_users_reached' => 'The maximum number of users has been reached.',
    'buy_now_buttons' => 'Buy Now Buttons',
    'landing_page' => 'Landing Page',
    'payment_type' => 'Payment Type',
    'form' => 'Form',
    'link' => 'Link',
    'fields' => 'Polja',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Note: the client and invoice are created even if the transaction isn\'t completed.',
    'buy_now_buttons_disabled' => 'This feature requires that a product is created and a payment gateway is configured.',
    'enable_buy_now_buttons_help' => 'Enable support for buy now buttons',
    'changes_take_effect_immediately' => 'Note: changes take effect immediately',
    'wepay_account_description' => 'Payment gateway for Invoice Ninja',
    'payment_error_code' => 'There was an error processing your payment [:code]. Please try again later.',
    'standard_fees_apply' => 'Fee: 2.9%/1.2% [Credit Card/Bank Transfer] + $0.30 per successful charge.',
    'limit_import_rows' => 'Data needs to be imported in batches of :count rows or less',
    'error_title' => 'Something went wrong',
    'error_contact_text' => 'If you\'d like help please email us at :mailaddress',
    'no_undo' => 'Warning: this can\'t be undone.',
    'no_contact_selected' => 'Molimo odaberite kontakt',
    'no_client_selected' => 'Molimo odaberite klijenta',

    'gateway_config_error' => 'It may help to set new passwords or generate new API keys.',
    'payment_type_on_file' => ':type on file',
    'invoice_for_client' => 'Invoice :invoice for :client',
    'intent_not_found' => 'Sorry, I\'m not sure what you\'re asking.',
    'intent_not_supported' => 'Sorry, I\'m not able to do that.',
    'client_not_found' => 'I wasn\'t able to find the client',
    'not_allowed' => 'Sorry, you don\'t have the needed permissions',
    'bot_emailed_invoice' => 'Your invoice has been sent.',
    'bot_emailed_notify_viewed' => 'I\'ll email you when it\'s viewed.',
    'bot_emailed_notify_paid' => 'I\'ll email you when it\'s paid.',
    'add_product_to_invoice' => 'Add 1 :product',
    'not_authorized' => 'Niste autorizovani',
    'bot_get_email' => 'Zdravo! (wave)<br/>Hvala što isprobavate Invoice Ninja Bot.<br/>Potrebno je da napravite besplatan nalog da biste ga koristili.<br/>Pošaljite mi email adresu Vašeg naloga pa možemo početi.',
    'bot_get_code' => 'Thanks! I\'ve sent a you an email with your security code.',
    'bot_welcome' => 'That\'s it, your account is verified.<br/>',
    'email_not_found' => 'I wasn\'t able to find an available account for :email',
    'invalid_code' => 'The code is not correct',
    'security_code_email_subject' => 'Security code for Invoice Ninja Bot',
    'security_code_email_line1' => 'This is your Invoice Ninja Bot security code.',
    'security_code_email_line2' => 'Note: it will expire in 10 minutes.',
    'bot_help_message' => 'I currently support:<br/>• Create\update\email an invoice<br/>• List products<br/>For example:<br/><i>invoice bob for 2 tickets, set the due date to next thursday and the discount to 10 percent</i>',
    'list_products' => 'Lista proizvoda',

    'include_item_taxes_inline' => 'Include <b>line item taxes in line total</b>',
    'created_quotes' => 'Successfully created :count quotes(s)',
    'limited_gateways' => 'Note: we support one credit card gateway per company.',

    'warning' => 'Upozorenje',
    'self-update' => 'Update',
    'update_invoiceninja_title' => 'Update Invoice Ninja',
    'update_invoiceninja_warning' => 'Before start upgrading Invoice Ninja create a backup of your database and files!',
    'update_invoiceninja_available' => 'Nova verzija Invoice Ninja je dostupna.',
    'update_invoiceninja_unavailable' => 'Nema dostupne nove verzije Invoice Ninja.',
    'update_invoiceninja_instructions' => 'Please install the new version <strong>:version</strong> by clicking the <em>Update now</em> button below. Afterwards you\'ll be redirected to the dashboard.',
    'update_invoiceninja_update_start' => 'Nadogradite odmah',
    'update_invoiceninja_download_start' => 'Download :version',
    'create_new' => 'Kreiraj novi',

    'toggle_navigation' => 'Toggle Navigation',
    'toggle_history' => 'Toggle History',
    'unassigned' => 'Unassigned',
    'task' => 'Task',
    'contact_name' => 'Contact Name',
    'city_state_postal' => 'City/State/Postal',
    'custom_field' => 'Custom Field',
    'account_fields' => 'Company Fields',
    'facebook_and_twitter' => 'Facebook and Twitter',
    'facebook_and_twitter_help' => 'Follow our feeds to help support our project',
    'reseller_text' => 'Note: the white-label license is intended for personal use, please email us at :email if you\'d like to resell the app.',
    'unnamed_client' => 'Unnamed Client',

    'day' => 'Dan',
    'week' => 'Week',
    'month' => 'Month',
    'inactive_logout' => 'You have been logged out due to inactivity',
    'reports' => 'Reports',
    'total_profit' => 'Total Profit',
    'total_expenses' => 'Total Expenses',
    'quote_to' => 'Quote to',

    // Limits
    'limit' => 'Limit',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'No Limits',
    'set_limits' => 'Podesi :gateway_type limit',
    'enable_min' => 'Enable min',
    'enable_max' => 'Enable max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'This invoice does not meet the limits for that payment type.',

    'date_range' => 'Date Range',
    'raw' => 'Raw',
    'raw_html' => 'Raw HTML',
    'update' => 'Update',
    'invoice_fields_help' => 'Drag and drop fields to change their order and location',
    'new_category' => 'New Category',
    'restore_product' => 'Vrati proizvod',
    'blank' => 'Blank',
    'invoice_save_error' => 'There was an error saving your invoice',
    'enable_recurring' => 'Enable Recurring',
    'disable_recurring' => 'Disable Recurring',
    'text' => 'Text',
    'expense_will_create' => 'expense will be created',
    'expenses_will_create' => 'expenses will be created',
    'created_expenses' => 'Successfully created :count expense(s)',

    'translate_app' => 'Help improve our translations with :link',
    'expense_category' => 'Expense Category',

    'go_ninja_pro' => 'Go Ninja Pro!',
    'go_enterprise' => 'Go Enterprise!',
    'upgrade_for_features' => 'Upgrade For More Features',
    'pay_annually_discount' => 'Pay annually for 10 months + 2 free!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Customize every aspect of your invoice!',
    'enterprise_upgrade_feature1' => 'Set permissions for multiple-users',
    'enterprise_upgrade_feature2' => 'Attach 3rd party files to invoices & expenses',
    'much_more' => 'Much More!',
    'all_pro_fetaures' => 'Plus sve pro mogućnosti!',

    'currency_symbol' => 'Symbol',
    'currency_code' => 'Code',

    'buy_license' => 'Buy License',
    'apply_license' => 'Apply License',
    'submit' => 'Submit',
    'white_label_license_key' => 'License Key',
    'invalid_white_label_license' => 'The white label license is not valid',
    'created_by' => 'Created by :name',
    'modules' => 'Modules',
    'financial_year_start' => 'First Month of the Year',
    'authentication' => 'Authentication',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Signature',
    'show_accept_invoice_terms' => 'Invoice Terms Checkbox',
    'show_accept_invoice_terms_help' => 'Require client to confirm that they accept the invoice terms.',
    'show_accept_quote_terms' => 'Quote Terms Checkbox',
    'show_accept_quote_terms_help' => 'Require client to confirm that they accept the quote terms.',
    'require_invoice_signature' => 'Invoice Signature',
    'require_invoice_signature_help' => 'Require client to provide their signature.',
    'require_quote_signature' => 'Quote Signature',
    'require_quote_signature_help' => 'Require client to provide their signature.',
    'i_agree' => 'I Agree To The Terms',
    'sign_here' => 'Please sign here:',
    'authorization' => 'Authorization',
    'signed' => 'Signed',

    // BlueVine
    'bluevine_promo' => 'Get flexible business lines of credit and invoice factoring using BlueVine.',
    'bluevine_modal_label' => 'Sign up with BlueVine',
    'bluevine_modal_text' => '<h3>Fast funding for your business. No paperwork.</h3>
<ul><li>Flexible business lines of credit and invoice factoring.</li></ul>',
    'bluevine_create_account' => 'Kreiraj nalog',
    'quote_types' => 'Get a quote for',
    'invoice_factoring' => 'Invoice factoring',
    'line_of_credit' => 'Line of credit',
    'fico_score' => 'Your FICO score',
    'business_inception' => 'Business Inception Date',
    'average_bank_balance' => 'Average bank account balance',
    'annual_revenue' => 'Annual revenue',
    'desired_credit_limit_factoring' => 'Desired invoice factoring limit',
    'desired_credit_limit_loc' => 'Desired line of credit limit',
    'desired_credit_limit' => 'Desired credit limit',
    'bluevine_credit_line_type_required' => 'You must choose at least one',
    'bluevine_field_required' => 'This field is required',
    'bluevine_unexpected_error' => 'An unexpected error occurred.',
    'bluevine_no_conditional_offer' => 'More information is required before getting a quote. Click continue below.',
    'bluevine_invoice_factoring' => 'Invoice Factoring',
    'bluevine_conditional_offer' => 'Conditional Offer',
    'bluevine_credit_line_amount' => 'Credit Line',
    'bluevine_advance_rate' => 'Advance Rate',
    'bluevine_weekly_discount_rate' => 'Weekly Discount Rate',
    'bluevine_minimum_fee_rate' => 'Minimum Fee',
    'bluevine_line_of_credit' => 'Line of Credit',
    'bluevine_interest_rate' => 'Interest Rate',
    'bluevine_weekly_draw_rate' => 'Weekly Draw Rate',
    'bluevine_continue' => 'Continue to BlueVine',
    'bluevine_completed' => 'BlueVine signup completed',

    'vendor_name' => 'Vendor',
    'entity_state' => 'State',
    'client_created_at' => 'Datum kreiranja',
    'postmark_error' => 'There was a problem sending the email through Postmark: :link',
    'project' => 'Project',
    'projects' => 'Projekti',
    'new_project' => 'New Project',
    'edit_project' => 'Edit Project',
    'archive_project' => 'Archive Project',
    'list_projects' => 'Lista projekata',
    'updated_project' => 'Successfully updated project',
    'created_project' => 'Successfully created project',
    'archived_project' => 'Successfully archived project',
    'archived_projects' => 'Uspešno arhivirano :count projekata',
    'restore_project' => 'Vrati projekat',
    'restored_project' => 'Uspešno vraćen projekat',
    'delete_project' => 'Izbriši projekat',
    'deleted_project' => 'Successfully deleted project',
    'deleted_projects' => 'Uspešno obrisano :count projekata',
    'delete_expense_category' => 'Delete category',
    'deleted_expense_category' => 'Successfully deleted category',
    'delete_product' => 'Izbriši proizvod',
    'deleted_product' => 'Successfully deleted product',
    'deleted_products' => 'Successfully deleted :count products',
    'restored_product' => 'Uspešno vraćen proizvod',
    'update_credit' => 'Update Credit',
    'updated_credit' => 'Successfully updated credit',
    'edit_credit' => 'Edit Credit',
    'realtime_preview' => 'Pregled u realnom vremenu',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => 'Replace the built-in PDF viewer in :chrome_link and :firefox_link.<br/>Enable this if your browser is automatically downloading the PDF.',
    'force_pdfjs' => 'Prevent Download',
    'redirect_url' => 'Redirect URL',
    'redirect_url_help' => 'Optionally specify a URL to redirect to after a payment is entered.',
    'save_draft' => 'Save Draft',
    'refunded_credit_payment' => 'Refunded credit payment',
    'keyboard_shortcuts' => 'Keyboard Shortcuts',
    'toggle_menu' => 'Toggle Menu',
    'new_...' => 'New ...',
    'list_...' => 'List ...',
    'created_at' => 'Datum kreiranja',
    'contact_us' => 'Contact Us',
    'user_guide' => 'User Guide',
    'promo_message' => 'Upgrade before :expires and get :amount OFF your first year of our Pro or Enterprise packages.',
    'discount_message' => ':amount off expires :expires',
    'mark_paid' => 'Mark Paid',
    'marked_sent_invoice' => 'Successfully marked invoice sent',
    'marked_sent_invoices' => 'Successfully marked invoices sent',
    'invoice_name' => 'Invoice',
    'product_will_create' => 'product will be created',
    'contact_us_response' => 'Thank you for your message! We\'ll try to respond as soon as possible.',
    'last_7_days' => 'Poslednjih 7 dana',
    'last_30_days' => 'Poslednjih 30 dana',
    'this_month' => 'This Month',
    'last_month' => 'Last Month',
    'current_quarter' => 'Current Quarter',
    'last_quarter' => 'Last Quarter',
    'last_year' => 'Last Year',
    'custom_range' => 'Custom Range',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Require',
    'license_expiring' => 'Note: Your license will expire in :count days, :link to renew it.',
    'security_confirmation' => 'Your email address has been confirmed.',
    'white_label_expired' => 'Your white label license has expired, please consider renewing it to help support our project.',
    'renew_license' => 'Renew License',
    'iphone_app_message' => 'Consider downloading our :link',
    'iphone_app' => 'iPhone app',
    'android_app' => 'Android app',
    'logged_in' => 'Logged In',
    'switch_to_primary' => 'Switch to your primary company (:name) to manage your plan.',
    'inclusive' => 'Inclusive',
    'exclusive' => 'Exclusive',
    'postal_city_state' => 'Postal/City/State',
    'phantomjs_help' => 'In certain cases the app uses :link_phantom to generate the PDF, install :link_docs to generate it locally.',
    'phantomjs_local' => 'Using local PhantomJS',
    'client_number' => 'Client Number',
    'client_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the client number.',
    'next_client_number' => 'The next client number is :number.',
    'generated_numbers' => 'Generated Numbers',
    'notes_reminder1' => 'First Reminder',
    'notes_reminder2' => 'Second Reminder',
    'notes_reminder3' => 'Third Reminder',
    'notes_reminder4' => 'Podsetnik',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'Tax Quote',
    'tax_invoice' => 'Tax Invoice',
    'emailed_invoices' => 'Successfully emailed invoices',
    'emailed_quotes' => 'Successfully emailed quotes',
    'website_url' => 'Website URL',
    'domain' => 'Domain',
    'domain_help' => 'Used in the client portal and when sending emails.',
    'domain_help_website' => 'Used when sending emails.',
    'import_invoices' => 'Import Invoices',
    'new_report' => 'New Report',
    'edit_report' => 'Edit Report',
    'columns' => 'Columns',
    'filters' => 'Filters',
    'sort_by' => 'Sortiraj po',
    'draft' => 'Draft',
    'unpaid' => 'Unpaid',
    'aging' => 'Aging',
    'age' => 'Age',
    'days' => 'Dani',
    'age_group_0' => '0 - 30 Days',
    'age_group_30' => '30 - 60 Days',
    'age_group_60' => '60 - 90 Days',
    'age_group_90' => '90 - 120 Days',
    'age_group_120' => '120+ Days',
    'invoice_details' => 'Invoice Details',
    'qty' => 'Quantity',
    'profit_and_loss' => 'Profit and Loss',
    'revenue' => 'Revenue',
    'profit' => 'Profit',
    'group_when_sorted' => 'Grupno sortiranje',
    'group_dates_by' => 'Group Dates By',
    'year' => 'Year',
    'view_statement' => 'View Statement',
    'statement' => 'Statement',
    'statement_date' => 'Statement Date',
    'mark_active' => 'Mark Active',
    'send_automatically' => 'Send Automatically',
    'initial_email' => 'Initial Email',
    'invoice_not_emailed' => 'This invoice hasn\'t been emailed.',
    'quote_not_emailed' => 'This quote hasn\'t been emailed.',
    'sent_by' => 'Sent by :user',
    'recipients' => 'Recipients',
    'save_as_default' => 'Save as default',
    'start_of_week_help' => 'Used by <b>date</b> selectors',
    'financial_year_start_help' => 'Used by <b>date range</b> selectors',
    'reports_help' => 'Shift + klik za sortiranje po više kolona. Ctrl + klik za poništavanje grupisanja.',
    'this_year' => 'This Year',

    // Updated login screen
    'ninja_tagline' => 'Create. Send. Get Paid.',
    'login_or_existing' => 'Ili se ulogujte sa povezanim nalogom.',
    'sign_up_now' => 'Sign Up Now',
    'not_a_member_yet' => 'Not a member yet?',
    'login_create_an_account' => 'Nalog je kreiran!',

    // New Client Portal styling
    'invoice_from' => 'Invoices From:',
    'email_alias_message' => 'We require each company to have a unique email address.<br/>Consider using an alias. ie, email+label@example.com',
    'full_name' => 'Full Name',
    'month_year' => 'MONTH/YEAR',
    'valid_thru' => 'Valid\nthru',

    'product_fields' => 'Product Fields',
    'custom_product_fields_help' => 'Add a field when creating a product or invoice and display the label and value on the PDF.',
    'freq_two_months' => 'Two months',
    'freq_yearly' => 'Annually',
    'profile' => 'Profile',
    'payment_type_help' => 'Sets the default <b>manual payment type</b>.',
    'industry_Construction' => 'Construction',
    'your_statement' => 'Your Statement',
    'statement_issued_to' => 'Statement issued to',
    'statement_to' => 'Statement to',
    'customize_options' => 'Customize options',
    'created_payment_term' => 'Successfully created payment term',
    'updated_payment_term' => 'Successfully updated payment term',
    'archived_payment_term' => 'Successfully archived payment term',
    'resend_invite' => 'Resend Invitation',
    'credit_created_by' => 'Credit created by payment :transaction_reference',
    'created_payment_and_credit' => 'Successfully created payment and credit',
    'created_payment_and_credit_emailed_client' => 'Successfully created payment and credit, and emailed client',
    'create_project' => 'Create project',
    'create_vendor' => 'Create vendor',
    'create_expense_category' => 'Create category',
    'pro_plan_reports' => ':link to enable reports by joining the Pro Plan',
    'mark_ready' => 'Mark Ready',

    'limits' => 'Limits',
    'fees' => 'Fees',
    'fee' => 'Fee',
    'set_limits_fees' => 'Set :gateway_type Limits/Fees',
    'fees_tax_help' => 'Enable line item taxes to set the fee tax rates.',
    'fees_sample' => 'The fee for a :amount invoice would be :total.',
    'discount_sample' => 'The discount for a :amount invoice would be :total.',
    'no_fees' => 'No Fees',
    'gateway_fees_disclaimer' => 'Warning: not all states/payment gateways allow adding fees, please review local laws/terms of service.',
    'percent' => 'Percent',
    'location' => 'Location',
    'line_item' => 'Line Item',
    'surcharge' => 'Surcharge',
    'location_first_surcharge' => 'Enabled - First surcharge',
    'location_second_surcharge' => 'Enabled - Second surcharge',
    'location_line_item' => 'Enabled - Line item',
    'online_payment_surcharge' => 'Online Payment Surcharge',
    'gateway_fees' => 'Naknade za kanal',
    'fees_disabled' => 'Fees are disabled',
    'gateway_fees_help' => 'Automatically add an online payment surcharge/discount.',
    'gateway' => 'Kanal',
    'gateway_fee_change_warning' => 'If there are unpaid invoices with fees they need to be updated manually.',
    'fees_surcharge_help' => 'Customize surcharge :link.',
    'label_and_taxes' => 'label and taxes',
    'billable' => 'Billable',
    'logo_warning_too_large' => 'The image file is too large.',
    'logo_warning_fileinfo' => 'Warning: To support gifs the fileinfo PHP extension needs to be enabled.',
    'logo_warning_invalid' => 'There was a problem reading the image file, please try a different format.',

    'error_refresh_page' => 'An error occurred, please refresh the page and try again.',
    'data' => 'Data',
    'imported_settings' => 'Successfully imported settings',
    'reset_counter' => 'Reset Counter',
    'next_reset' => 'Next Reset',
    'reset_counter_help' => 'Automatically reset the invoice and quote counters.',
    'auto_bill_failed' => 'Auto-billing for invoice :invoice_number failed',
    'online_payment_discount' => 'Online Payment Discount',
    'created_new_company' => 'Successfully created new company',
    'fees_disabled_for_gateway' => 'Fees are disabled for this gateway.',
    'logout_and_delete' => 'Log Out/Delete Account',
    'tax_rate_type_help' => 'Uključujuće poreske stope podešavaju cenu stavke prilikom izbora. <br/>Samo iskjlučujuće poreske stope mogu biti korišćene kao podrazumevane.',
    'invoice_footer_help' => 'Use $pageNumber and $pageCount to display the page information.',
    'credit_note' => 'Credit Note',
    'credit_issued_to' => 'Credit issued to',
    'credit_to' => 'Credit to',
    'your_credit' => 'Your Credit',
    'credit_number' => 'Credit Number',
    'create_credit_note' => 'Create Credit Note',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Error: The gateways table has incorrect ids.',
    'purge_data' => 'Purge Data',
    'delete_data' => 'Delete Data',
    'purge_data_help' => 'Izbriši sve podatke, ali zadrži nalog i podešavanja.',
    'cancel_account_help' => 'Permanently delete the account along with all data and setting.',
    'purge_successful' => 'Uspešno očišćeni podatci kompanije',
    'forbidden' => 'Forbidden',
    'purge_data_message' => 'Warning: This will permanently erase your data, there is no undo.',
    'contact_phone' => 'Contact Phone',
    'contact_email' => 'Contact Email',
    'reply_to_email' => 'Reply-To Email',
    'reply_to_email_help' => 'Specify the reply-to address for client emails.',
    'bcc_email_help' => 'Privately include this address with client emails.',
    'import_complete' => 'Your import has successfully completed.',
    'confirm_account_to_import' => 'Please confirm your account to import data.',
    'import_started' => 'Your import has started, we\'ll send you an email once it completes.',
    'listening' => 'Listening...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Voice Commands',
    'sample_commands' => 'Sample commands',
    'voice_commands_feedback' => 'We\'re actively working to improve this feature, if there\'s a command you\'d like us to support please email us at :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Novčana uputnica',
    'archived_products' => 'Successfully archived :count products',
    'recommend_on' => 'We recommend <b>enabling</b> this setting.',
    'recommend_off' => 'We recommend <b>disabling</b> this setting.',
    'notes_auto_billed' => 'Auto-billed',
    'surcharge_label' => 'Surcharge Label',
    'contact_fields' => 'Contact Fields',
    'custom_contact_fields_help' => 'Dodajte polje kada kreirate kontakt i opciono prikažite oznaku i vrednost na PDF-u.',
    'datatable_info' => 'Showing :start to :end of :total entries',
    'credit_total' => 'Credit Total',
    'mark_billable' => 'Mark billable',
    'billed' => 'Billed',
    'company_variables' => 'Company Variables',
    'client_variables' => 'Client Variables',
    'invoice_variables' => 'Invoice Variables',
    'navigation_variables' => 'Navigation Variables',
    'custom_variables' => 'Custom Variables',
    'invalid_file' => 'Invalid file type',
    'add_documents_to_invoice' => 'Dodaj dokumente uz Račun',
    'mark_expense_paid' => 'Mark paid',
    'white_label_license_error' => 'Failed to validate the license, check storage/logs/laravel-error.log for more details.',
    'plan_price' => 'Plan Price',
    'wrong_confirmation' => 'Incorrect confirmation code',
    'oauth_taken' => 'Ovaj nalog je već registrovan',
    'emailed_payment' => 'Uplata uspešno poslata putem elektronske pošte',
    'email_payment' => 'Pošalji uplatu ePoštom',
    'invoiceplane_import' => 'Koristite :link za migraciju Vaših podataka iz  InvoicePlane.',
    'duplicate_expense_warning' => 'Upozorenje: Ovaj :link je duplikat',
    'expense_link' => 'trošak',
    'resume_task' => 'Nastavi Zadatak',
    'resumed_task' => 'Uspešno nastavljen zadatak',
    'quote_design' => 'Dizajn ponude',
    'default_design' => 'Standardni Dizajn',
    'custom_design1' => 'Prilagođeni Dizajn 1',
    'custom_design2' => 'Prilagođeni Dizajn 2',
    'custom_design3' => 'Prilagođeni Dizajn 3',
    'empty' => 'Prazno',
    'load_design' => 'Učitaj Dizajn',
    'accepted_card_logos' => 'Logoi Prihvaćenih Kartica',
    'phantomjs_local_and_cloud' => 'Koristi se PhantomJS, u slučaju problema pokušava se sa phantomjscloud.com.',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Ključ za analitiku',
    'analytics_key_help' => 'Prati uplatu upotrebom linka :link',
    'start_date_required' => 'Datum početka je obavezno polje',
    'application_settings' => 'Podešavanja apliakcije',
    'database_connection' => 'Konekcija sa bazom',
    'driver' => 'Drajver',
    'host' => 'Host',
    'database' => 'Baza podataka',
    'test_connection' => 'Testiranje konekcije',
    'from_name' => 'Od Ime',
    'from_address' => 'Od Adresa',
    'port' => 'Port',
    'encryption' => 'Enkripcija',
    'mailgun_domain' => 'Mailgun Domen',
    'mailgun_private_key' => 'Mailgun privatni ključ',
    'send_test_email' => 'Pošalji probnu email poruku',
    'select_label' => 'Selektuj oznaku',
    'label' => 'Oznaka',
    'service' => 'Usluga',
    'update_payment_details' => 'Osveži detalje plaćanja',
    'updated_payment_details' => 'Uspešno izmenjeni detalji plaćanja',
    'update_credit_card' => 'Izmeni kreditnu karticu',
    'recurring_expenses' => 'Redovni troškovi',
    'recurring_expense' => 'Redovni trošak',
    'new_recurring_expense' => 'Novi redovn trošak',
    'edit_recurring_expense' => 'Izmena redovnih troškova',
    'archive_recurring_expense' => 'Arhiviranje redovnih troškova',
    'list_recurring_expense' => 'Lista redovnih troškova',
    'updated_recurring_expense' => 'Uspešno izmenjen redovni trošak',
    'created_recurring_expense' => 'Uspešno kreiran redovni trošak',
    'archived_recurring_expense' => 'Uspešno arhiviran redovni trošak',
    'restore_recurring_expense' => 'Vraćanje ponavljajućih troškova',
    'restored_recurring_expense' => 'Uspešno obnovljen redovni trošak',
    'delete_recurring_expense' => 'Brisanje ponavljajućih troškova',
    'deleted_recurring_expense' => 'Uspešno obrisan projekat',
    'view_recurring_expense' => 'Pogledaj redovne troškove',
    'taxes_and_fees' => 'Porezi i naplate',
    'import_failed' => 'Neuspešan uvoz',
    'recurring_prefix' => 'Prefiks koji se ponavlja',
    'options' => 'Opcije',
    'credit_number_help' => 'Odredite prefiks ili koristite prilagođeni uzorak za dinamičko postavljanje brojeva računa.',
    'next_credit_number' => 'Sledeći kreditni broj je :number.',
    'padding_help' => 'Količina nula koje će se dodati na broj.',
    'import_warning_invalid_date' => 'Upozorenje: Format datuma nije validan.',
    'product_notes' => 'Zabeleške Proizvoda',
    'app_version' => 'Verzija aplikacije',
    'ofx_version' => 'OFX Verzija',
    'gateway_help_23' => ':link za preuzimanje Stripe API ključeva.',
    'error_app_key_set_to_default' => 'Greška: APP_KEY je postavljen na podrazumevanu vrednost, da bi se ažurirao napravite rezervnu kopiju baze podataka, a zatim pokrenite <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Izmeni honorar',
    'late_fee_amount' => 'Iznos honorara',
    'late_fee_percent' => 'Procenat honorara',
    'late_fee_added' => 'Honorar dodat :date',
    'download_invoice' => 'Preuzmi Račun',
    'download_quote' => 'Preuzmite ponudu',
    'invoices_are_attached' => 'Vaš račun u PDF formatu je zakačen.',
    'downloaded_invoice' => 'e-poruka će biti poslata sa PDF računom u prilogu',
    'downloaded_quote' => 'e-poruka će biti poslata sa PDF ponudom u prilogu',
    'downloaded_invoices' => 'e-poruka će biti poslata sa PDF računom u prilogu',
    'downloaded_quotes' => 'e-poruka će biti poslata sa PDF ponudom u prilogu',
    'clone_expense' => 'Kloniraj troškove',
    'default_documents' => 'Podrazumevani dokumenti',
    'send_email_to_client' => 'Pošalji e-poruku klijentu',
    'refund_subject' => 'Proces Povraćaja',
    'refund_body' => 'Odobrili ste vraćanje noca od :amount za račun :invoice_number.',

    'currency_us_dollar' => 'Američki dolar',
    'currency_british_pound' => 'Britanska funta',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'Južno afrički Rand',
    'currency_danish_krone' => 'Danska kruna',
    'currency_israeli_shekel' => 'Izraelski Šekel',
    'currency_swedish_krona' => 'Švedska kruna',
    'currency_kenyan_shilling' => 'Kenijski šiling',
    'currency_canadian_dollar' => 'Kanadski dolar',
    'currency_philippine_peso' => 'Filipinski pezos',
    'currency_indian_rupee' => 'Indijska Rupija',
    'currency_australian_dollar' => 'Australijski dolar',
    'currency_singapore_dollar' => 'Singapurski dolar',
    'currency_norske_kroner' => 'Norveška kruna',
    'currency_new_zealand_dollar' => 'Novo Zelandski dolar',
    'currency_vietnamese_dong' => 'Vijetnamski dong',
    'currency_swiss_franc' => 'Švajcarski franak',
    'currency_guatemalan_quetzal' => 'Gvatemalski Kvecal',
    'currency_malaysian_ringgit' => 'Malezijski Ringgit',
    'currency_brazilian_real' => 'Brazilski real',
    'currency_thai_baht' => 'Tajlandski baht',
    'currency_nigerian_naira' => 'Nigerijska Naira',
    'currency_argentine_peso' => 'Argentinski pezos',
    'currency_bangladeshi_taka' => 'Bangladeška Taka',
    'currency_united_arab_emirates_dirham' => 'UAE Dirham',
    'currency_hong_kong_dollar' => 'Hongkoški dolar',
    'currency_indonesian_rupiah' => 'Indonežanska rupja',
    'currency_mexican_peso' => 'Meksički pezos',
    'currency_egyptian_pound' => 'Egipatska funta',
    'currency_colombian_peso' => 'Kolumbijski pezos',
    'currency_west_african_franc' => 'Zadapno afrički Franak',
    'currency_chinese_renminbi' => 'Kineski Juan',
    'currency_rwandan_franc' => 'Ruandski Franak',
    'currency_tanzanian_shilling' => 'Tanzanijski šiling',
    'currency_netherlands_antillean_guilder' => 'Holandsko Antilski Gvilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad i Tobago Dolar',
    'currency_east_caribbean_dollar' => 'Istočno Karipski Dolar',
    'currency_ghanaian_cedi' => 'Ganski Kedi',
    'currency_bulgarian_lev' => 'Bugarski lev',
    'currency_aruban_florin' => 'Arubski Florin',
    'currency_turkish_lira' => 'Turska lira',
    'currency_romanian_new_leu' => 'Rumunski Novi Lev',
    'currency_croatian_kuna' => 'Hrvatska kruna',
    'currency_saudi_riyal' => 'Saudijski Rial',
    'currency_japanese_yen' => 'Japanski jen',
    'currency_maldivian_rufiyaa' => 'Maldivska Rufija',
    'currency_costa_rican_colon' => 'Kostarikanski Kolon',
    'currency_pakistani_rupee' => 'Pakistanska Rupija',
    'currency_polish_zloty' => 'Poljski zlot',
    'currency_sri_lankan_rupee' => 'Šri Lankanska Rupija',
    'currency_czech_koruna' => 'Češka kruna',
    'currency_uruguayan_peso' => 'Urugvajski Pezos',
    'currency_namibian_dollar' => 'Namibijski dolar',
    'currency_tunisian_dinar' => 'Tunižanski dinar',
    'currency_russian_ruble' => 'Ruska rublja',
    'currency_mozambican_metical' => 'Mozambijski Metikal',
    'currency_omani_rial' => 'Omanski Rial',
    'currency_ukrainian_hryvnia' => 'Ukrajinska Hrivnija',
    'currency_macanese_pataca' => 'Makanijska Pataka',
    'currency_taiwan_new_dollar' => 'Tajvanski novi dolar',
    'currency_dominican_peso' => 'Dominikanski pezos',
    'currency_chilean_peso' => 'Čileanski pezos',
    'currency_icelandic_krona' => 'Islandska Kruna',
    'currency_papua_new_guinean_kina' => 'Papua Novo Gvinejska Kina',
    'currency_jordanian_dinar' => 'Jordanski dinar',
    'currency_myanmar_kyat' => 'Mjanmarski Kjat',
    'currency_peruvian_sol' => 'Peruanski Sol',
    'currency_botswana_pula' => 'Bocvanska Pula',
    'currency_hungarian_forint' => 'Mađarska forinta',
    'currency_ugandan_shilling' => 'Ugandski Šiling',
    'currency_barbadian_dollar' => 'Barbadoski dolar',
    'currency_brunei_dollar' => 'Brunejski dolar',
    'currency_georgian_lari' => 'Gruzijski lari',
    'currency_qatari_riyal' => 'Katarski Rial',
    'currency_honduran_lempira' => 'Hondurasa lempira',
    'currency_surinamese_dollar' => 'Surinamijski Dolar',
    'currency_bahraini_dinar' => 'Bahreinski dinar',
    'currency_venezuelan_bolivars' => 'Venecuelanski bolivari',
    'currency_south_korean_won' => 'Južnokorejski von',
    'currency_moroccan_dirham' => 'Marokanski diram',
    'currency_jamaican_dollar' => 'Jamajčanski dolar',
    'currency_angolan_kwanza' => 'Angolska kvanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanski Lek',
    'currency_serbian_dinar' => 'Srpski Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'Nadamo se da uživate u korišćenju aplikacije. <br/> Bili bismo veoma zahvalni ako biste razmotrili :link.',
    'writing_a_review' => 'napišite ocenu',

    'use_english_version' => 'Obavezno koristite englesku verziju fajla.<br/>Koristimo imena kolona radi pronalaska polja.',
    'tax1' => 'Prvi porez',
    'tax2' => 'Drugi porez',
    'fee_help' => 'Provizija posrednika je trošak za pristup finansijskoj mreži koja obrađuje online plaćanje.',
    'format_export' => 'Format za izvoz',
    'custom1' => 'Prvo prilagođeno',
    'custom2' => 'Drugo prilagođeno',
    'contact_first_name' => 'Ime kontakta',
    'contact_last_name' => 'Prezime kontakta',
    'contact_custom1' => 'Prvo prilagođeno kontakta',
    'contact_custom2' => 'Drugo prilagođeno kontakta',
    'currency' => 'Valuta',
    'ofx_help' => 'Za rešavanje problema vidite komentare na :ofxhome_link i testirajte sa :ofxget_link.',
    'comments' => 'komentari',

    'item_product' => 'Element proizvod',
    'item_notes' => 'Element beleške',
    'item_cost' => 'Element cena',
    'item_quantity' => 'Element količina',
    'item_tax_rate' => 'Element poreska stopa',
    'item_tax_name' => 'Element naziv poreske stope',
    'item_tax1' => 'Stavka Porez1',
    'item_tax2' => 'Stavka Porez2',

    'delete_company' => 'Izbriši kompaniju',
    'delete_company_help' => 'Permanently delete the company along with all data and setting.',
    'delete_company_message' => 'Upozorenje: Ovo će potpuno obrisati podatke o Vašooj komplaniji, nema mogućnosti povratka podataka.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'Kupon je primenjen, Vaš nalog je unapređen na pro za jednu godinu.',

    'contact_us_help' => 'Ako prijavljujete grešku, molimo dodajte relevantne zapise it storage/logs/laravel-error.log',
    'include_errors' => 'Uključujući greške',
    'include_errors_help' => 'Dodajte :link iz storage/logs/laravel-error.log',
    'recent_errors' => 'skore greške',
    'customer' => 'Kupac',
    'customers' => 'Kupci',
    'created_customer' => 'Uspešno kreiran kupac',
    'created_customers' => 'Uspešno kreirano :count kupaca',

    'purge_details' => 'Podaci Vaše organizacije (:account) su uspešno uništeni.',
    'deleted_company' => 'Uspešno izbrisana kompanija',
    'deleted_account' => 'Uspešno otkazan nalog',
    'deleted_company_details' => 'Vaša kompanija (:account) je uspešno izbrisana.',
    'deleted_account_details' => 'Vaš nalog (:account) je uspešno izbrisan.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Prihvati Alipay',
    'enable_sofort' => 'Prihvati transfere EU banaka',
    'stripe_alipay_help' => 'Ovaj kanal takođe mora biti aktiviran  :link.',
    'calendar' => 'Kalendar',
    'pro_plan_calendar' => ':link za omogućavanje kalendara aktivacijom Pro plana',

    'what_are_you_working_on' => 'Na čemu radite ?',
    'time_tracker' => 'Praćenje vremena',
    'refresh' => 'Osveži',
    'filter_sort' => 'Filter/Sortiranje',
    'no_description' => 'Nema opisa',
    'time_tracker_login' => 'Login za praćenje vremena',
    'save_or_discard' => 'Sačuvaj ili otkaži izmene',
    'discard_changes' => 'Otkaži izmene',
    'tasks_not_enabled' => 'Zadatak nije omogućen.',
    'started_task' => 'Uspešno pokrenut zadatak',
    'create_client' => 'Kreiraj klijenta',

    'download_desktop_app' => 'Preuzmi desktop aplikaciju',
    'download_iphone_app' => 'Preuzmi aplikaciju za iPhone',
    'download_android_app' => 'Preuzmi aplikaciju za Android',
    'time_tracker_mobile_help' => 'Dupli dodir na zadatak za selekciju',
    'stopped' => 'Zaustavljeno',
    'ascending' => 'Rastuće',
    'descending' => 'Opadajuće',
    'sort_field' => 'Sortiraj po',
    'sort_direction' => 'Pravac',
    'discard' => 'Otkaži',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'minuti',
    'time_hr' => 'sat',
    'time_hrs' => 'sati',
    'clear' => 'Očisti',
    'warn_payment_gateway' => 'Napomena: prihvatanje online plaćanja zahteva posrednika za plaćanje, :link da biste dodali jednog.',
    'task_rate' => 'Stopa zadatka',
    'task_rate_help' => 'Postavite podrazumevanu stopu za fakturisan zadatak.',
    'past_due' => 'Van valute',
    'document' => 'Dokument',
    'invoice_or_expense' => 'Račun/Trošak',
    'invoice_pdfs' => 'PDF Računa',
    'enable_sepa' => 'Prihvati SEPA',
    'enable_bitcoin' => 'Prihvati Bitcoin-e',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Unosom broja računa (IBAN) i potvrdom ovog plaćanja, dajete dozvolu :company i Stripe-u, našem partneru za plaćanje, da pošalju nalog Vašoj banci za prenos sredstava u skladu sa ovim nalogom. Imate pravo na povraćaj novca u skladu sa ugovorom sa Vašom bankom. Povraćaj može biti zatražen najkasnije 8 nedelja od dana prenosa sredstava.',
    'recover_license' => 'Povrati licencu',
    'purchase' => 'Kupovina',
    'recover' => 'Povrati',
    'apply' => 'Prihvati',
    'recover_white_label_header' => 'Povrati licencu bele oznake',
    'apply_white_label_header' => 'Aktivirajte licencu bele oznake',
    'videos' => 'Video',
    'video' => 'Video',
    'return_to_invoice' => 'Povratak na račun',
    'gateway_help_13' => 'Za korištenje ITN ostavite polje PDT ključa prazno.',
    'partial_due_date' => 'Datum dospeća avansa',
    'task_fields' => 'Polja zadatka',
    'product_fields_help' => 'Prevlačenjem polja se menja redosled',
    'custom_value1' => 'Prilagođena Vrednost',
    'custom_value2' => 'Prilagođena Vrednost',
    'enable_two_factor' => 'Dvostepena autorizacija',
    'enable_two_factor_help' => 'Koristite Vaš telefon da biste potvrdili identitet prilikom prijave',
    'two_factor_setup' => 'Podešavanje dvostepene autorizacije',
    'two_factor_setup_help' => 'Očitajte bar kod uz pomoć :link kompatibilne aplikacije.',
    'one_time_password' => 'Jednokratna lozinka',
    'set_phone_for_two_factor' => 'Unesite broj mobilnog telefona za rezervu.',
    'enabled_two_factor' => 'Dvostepena autorizacija uspešno aktivirana',
    'add_product' => 'Dodaj proizvod',
    'email_will_be_sent_on' => 'Napomena: e-poruka će biti poslata :date.',
    'invoice_product' => 'Proizvod na računu',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Greška: lokalni prostor za skladištenje nije dostupan',
    'your_password_reset_link' => 'Link za resetovanje lozinke',
    'subdomain_taken' => 'Poddomen se već koristi',
    'client_login' => 'Client Login',
    'converted_amount' => 'Konvertovani iznos',
    'default' => 'Podrazumevano',
    'shipping_address' => 'Adresa za slanje',
    'bllling_address' => 'Adresa računa',
    'billing_address1' => 'Adresa naplate - Ulica',
    'billing_address2' => 'Adresa računa - Stan/Spartman',
    'billing_city' => 'Adresa naplate - Grad',
    'billing_state' => 'Adresa naplate - Provincija/Pokrajina',
    'billing_postal_code' => 'Adresa naplate - Poštanski broj',
    'billing_country' => 'Adresa naplate - Država',
    'shipping_address1' => 'Adresa za slanje ulica',
    'shipping_address2' => 'Adresa za slanje stan/apartman',
    'shipping_city' => 'Adresa za slanje grad',
    'shipping_state' => 'Adresa za slanje - Provincija/Pokrajina',
    'shipping_postal_code' => 'Adresa za slanje poštanski broj',
    'shipping_country' => 'Adresa za slanje država',
    'classify' => 'Klasifikuj',
    'show_shipping_address_help' => 'Zahtevajte od klijenta da unesu adresu za isporuku',
    'ship_to_billing_address' => 'Slanje na adresu za naplatu',
    'delivery_note' => 'Otpremnica',
    'show_tasks_in_portal' => 'Prikaži zadatke u portalu klijenta',
    'cancel_schedule' => 'Otkaži raspored',
    'scheduled_report' => 'Izveštaj rasporeda',
    'scheduled_report_help' => 'Pošalji :report izveštaj kao :format na :email',
    'created_scheduled_report' => 'Uspešno zakazan raspored',
    'deleted_scheduled_report' => 'Uspešno otkazan zakazani raspored',
    'scheduled_report_attached' => 'Vaš planirani :type izveštaj je u prilogu.',
    'scheduled_report_error' => 'Greška pri kreiranju planiranog izveštaja',
    'invalid_one_time_password' => 'Neispravna jednokratna lozinka',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Prihvati Apple Pay i Pay with Google',
    'requires_subdomain' => 'Ovaj način plaćanja zahteva da :link.',
    'subdomain_is_set' => 'poddomen je postavljen',
    'verification_file' => 'Verifikacioni fajl',
    'verification_file_missing' => 'Datoteka za verifikaciju je neophodna za prihvatanje plaćanja.',
    'apple_pay_domain' => 'Koristi <code>:domain</code> kao domen u :link.',
    'apple_pay_not_supported' => 'Nažalost, Apple/Google Pay ne podržava Vaš pregledač',
    'optional_payment_methods' => 'Opcione metode plaćanja',
    'add_subscription' => 'Dodaj pretplatu',
    'target_url' => 'Cilj',
    'target_url_help' => 'Kada se desi izabrani događaj aplikacija će poslati objekat na ciljani link.',
    'event' => 'Događaj',
    'subscription_event_1' => 'Kreiran klijent',
    'subscription_event_2' => 'Kreiran račun',
    'subscription_event_3' => 'Kreirane ponude',
    'subscription_event_4' => 'Kreirano plaćanje',
    'subscription_event_5' => 'Kreiran dobavljač',
    'subscription_event_6' => 'Ažurirana Ponuda',
    'subscription_event_7' => 'Izbrisane ponude',
    'subscription_event_8' => 'Ažuriran Račun',
    'subscription_event_9' => 'Izbrisani računi',
    'subscription_event_10' => 'Ažuriran klijent',
    'subscription_event_11' => 'Izbrisani klijenti',
    'subscription_event_12' => 'Izbrisana plaćanja',
    'subscription_event_13' => 'Ažuriran dobavljač',
    'subscription_event_14' => 'Izbrisani dobavljači',
    'subscription_event_15' => 'Kreirani troškovi',
    'subscription_event_16' => 'Ažuriran trošak',
    'subscription_event_17' => 'Izbrisani troškovi',
    'subscription_event_18' => 'Kreiran zadatak',
    'subscription_event_19' => 'Ažuriran zadatak',
    'subscription_event_20' => 'Obrisan zadatak',
    'subscription_event_21' => 'Odobrene ponude',
    'subscriptions' => 'Pretplata',
    'updated_subscription' => 'Uspešno osvežena pretplata',
    'created_subscription' => 'Uspešno kreirana pretplata',
    'edit_subscription' => 'Izmeni Pretplatu',
    'archive_subscription' => 'Arhiviraj Pretplatu',
    'archived_subscription' => 'Uspešno arhivirana pretplata',
    'project_error_multiple_clients' => 'Projekti ne mogu pripadati različitim klijentima',
    'invoice_project' => 'Naplati Projekat',
    'module_recurring_invoice' => 'Ponavljajući Računi',
    'module_credit' => 'Krediti',
    'module_quote' => 'Ponude',
    'module_task' => 'Zadatci & Projekti',
    'module_expense' => 'Troškovi i Dobavljači',
    'module_ticket' => 'Tiketi',
    'reminders' => 'Podsetnici',
    'send_client_reminders' => 'Pošalji podsetnike e-poštom',
    'can_view_tasks' => 'Zadaci su vidljivi na portalu',
    'is_not_sent_reminders' => 'Podsetnik nije poslat',
    'promotion_footer' => 'Vaša promocija će uskoro isteći, kliknite :link za nadogradnju.',
    'unable_to_delete_primary' => 'Napomena: pre brisanja kompanije potrebno je da izbrišete sve povezane komplanije.',
    'please_register' => 'Molim Vas da registrujete svoj nalog',
    'processing_request' => 'Procesiranje zahteva',
    'mcrypt_warning' => 'Upozorenje: Mcrypt je zastareo, pokrenite :command da biste ažurirali vaše šifrovanje.',
    'edit_times' => 'Izmeni Vremena',
    'inclusive_taxes_help' => 'Uključujući <b>porez u ceni </b>',
    'inclusive_taxes_notice' => 'Ova podešavanja ne mogu biti promenjena kada je račun izdat.',
    'inclusive_taxes_warning' => 'Upozorenje: postojeći računi treba da budu ponovo snimljeni',
    'copy_shipping' => 'Kopiraj adresu za slanje',
    'copy_billing' => 'Kopiraj adresu za naplatu',
    'quote_has_expired' => 'Ponuda je istekla, molimo kontaktirajte trgovca.',
    'empty_table_footer' => 'Prikazuje 0 do 0 od 0 unosa',
    'do_not_trust' => 'Nemoj zapamtiti ovaj uređaj',
    'trust_for_30_days' => 'Validno 30 dana',
    'trust_forever' => 'Validno zauvek',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Spreman za rad',
    'in_progress' => 'U toku',
    'add_status' => 'Dodaj status',
    'archive_status' => 'Arhiviraj status',
    'new_status' => 'Novi status',
    'convert_products' => 'Konvertuj proizvode',
    'convert_products_help' => 'Automatski konvertuj cene proizvoda u valutu klijenta',
    'improve_client_portal_link' => 'Izaberite poddomen da biste skratili link na klijentski portal.',
    'budgeted_hours' => 'Budžetirani sati',
    'progress' => 'Napredak',
    'view_project' => 'Pogledaj Projekat',
    'summary' => 'Suma',
    'endless_reminder' => 'Beskrajni podsetnik',
    'signature_on_invoice_help' => 'Dodajte sledeći kod da biste prikazali klijentov potpis u PDF-u.',
    'signature_on_pdf' => 'Prikaži u PDF-u',
    'signature_on_pdf_help' => 'Prikazite potpis klijenta na PDF-u računa/ponude.',
    'expired_white_label' => 'Licenca bele oznake je istekla',
    'return_to_login' => 'Povratak na logovanje',
    'convert_products_tip' => 'Napomena: dodajte :link sa nazivom ":name" da biste videli kurs.',
    'amount_greater_than_balance' => 'Iznos je veći od iznosa za uplatu, kreiraće se kredit u vrednosti razlike.',
    'custom_fields_tip' => 'Koristite <code>Oznaka|Opcija1,Opcija2</code> za prikaz padajuće liste.',
    'client_information' => 'Informacije Klijenta',
    'updated_client_details' => 'Uspešno osveženi detalji klijenta',
    'auto' => 'Auto',
    'tax_amount' => 'Iznos poreza',
    'tax_paid' => 'Porez Plaćen',
    'none' => 'Nema',
    'proposal_message_button' => 'Za pregled vaše ponude iznosa :amount, kliknite dugme ispod.',
    'proposal' => 'Ponuda',
    'proposals' => 'Ponude',
    'list_proposals' => 'Listaj Ponude',
    'new_proposal' => 'Nova ponuda',
    'edit_proposal' => 'Izmeni ponudu',
    'archive_proposal' => 'Arhiviraj ponudu',
    'delete_proposal' => 'Izbriši ponudu',
    'created_proposal' => 'Uspešno kreirana ponuda',
    'updated_proposal' => 'Uspešno izmenjena ponuda',
    'archived_proposal' => 'Uspešno arhivirana ponuda',
    'deleted_proposal' => 'Uspešno kreirana ponuda',
    'archived_proposals' => 'Uspešno arhivirano :count ponuda',
    'deleted_proposals' => 'Uspešno arhivirano :count ponuda',
    'restored_proposal' => 'Uspešno vraćena ponuda',
    'restore_proposal' => 'Vrati ponudu',
    'snippet' => 'Isečak',
    'snippets' => 'Isečci',
    'proposal_snippet' => 'Isečak',
    'proposal_snippets' => 'Isečci',
    'new_proposal_snippet' => 'Novi Isečak',
    'edit_proposal_snippet' => 'Izmeni Isečak',
    'archive_proposal_snippet' => 'Arhiviraj Isečak',
    'delete_proposal_snippet' => 'Obriši Isečak',
    'created_proposal_snippet' => 'Uspešno kreiran isečak',
    'updated_proposal_snippet' => 'Uspešno izmenjen isečak',
    'archived_proposal_snippet' => 'Uspešno arhiviran isečak',
    'deleted_proposal_snippet' => 'Uspešno arhiviran isečak',
    'archived_proposal_snippets' => 'Uspešno arhivirano :coun isečaka',
    'deleted_proposal_snippets' => 'Uspešno arhivirano :coun isečaka',
    'restored_proposal_snippet' => 'Uspešno vraćen isečak',
    'restore_proposal_snippet' => 'Vrati isečak',
    'template' => 'Šablon',
    'templates' => 'Šabloni',
    'proposal_template' => 'Šablon',
    'proposal_templates' => 'Šabloni',
    'new_proposal_template' => 'Novi šablon',
    'edit_proposal_template' => 'Izmeni šablon',
    'archive_proposal_template' => 'Arhiviraj šablon',
    'delete_proposal_template' => 'Izbriši šablon',
    'created_proposal_template' => 'Uspešno kreiran šablon',
    'updated_proposal_template' => 'Uspešno osvežen šablon',
    'archived_proposal_template' => 'Uspešno arhiviran šablon',
    'deleted_proposal_template' => 'Uspešno arhiviran šablon',
    'archived_proposal_templates' => 'Uspešno arhivirano :count šablona',
    'deleted_proposal_templates' => 'Uspešno arhivirano :count šablona',
    'restored_proposal_template' => 'Uspešno vraćen šablon',
    'restore_proposal_template' => 'Vrati šablon',
    'proposal_category' => 'Kategorija',
    'proposal_categories' => 'Kategorije',
    'new_proposal_category' => 'Nova kategorija',
    'edit_proposal_category' => 'Izmeni kategoriju',
    'archive_proposal_category' => 'Arhiviraj kategoriju',
    'delete_proposal_category' => 'Izbriši kategoriju',
    'created_proposal_category' => 'Uspešno kreirana kategorija',
    'updated_proposal_category' => 'Uspešno izmenjena kategorija',
    'archived_proposal_category' => 'Uspešno arhivirana kategorija',
    'deleted_proposal_category' => 'Uspešno arhivirana kategorija',
    'archived_proposal_categories' => 'Uspešno arhivirano :count  kategorija',
    'deleted_proposal_categories' => 'Uspešno arhivirano :count kategorija',
    'restored_proposal_category' => 'Uspešno vraćena kategorija',
    'restore_proposal_category' => 'Vrati kategoriju',
    'delete_status' => 'Izbriši status',
    'standard' => 'Standardno',
    'icon' => 'Ikona',
    'proposal_not_found' => 'Zahtevana ponuda nije dostupna',
    'create_proposal_category' => 'Kreiraj kategoriju',
    'clone_proposal_template' => 'Kloniraj šablon',
    'proposal_email' => 'ePošta Ponude',
    'proposal_subject' => 'Nova ponuda broj :number od :account',
    'proposal_message' => 'Da pregledate Vašu ponudu za iznos :amount, kliknite na donji link.',
    'emailed_proposal' => 'Uspešno poslata ponuda',
    'load_template' => 'Učitaj šablon',
    'no_assets' => 'Nema slika, prevuci za postavljanje',
    'add_image' => 'Dodaj fotografiju',
    'select_image' => 'Izaberi fotografiju',
    'upgrade_to_upload_images' => 'Nadogradite vaš nalog na korporativni plan za opciju slanja slika',
    'delete_image' => 'Izbriši fotografiju',
    'delete_image_help' => 'Upozorenje: brisanje fotografije će je ukloniti sa svih ponuda.',
    'amount_variable_help' => 'Napomena: polje računa $amount će koristiti polje za avans/depozit ako postoji, inače će koristiti iznos računa.',
    'taxes_are_included_help' => 'Napomena: Uključujuće takse su omogućene.',
    'taxes_are_not_included_help' => 'Napomena: Uključujuće takse nisu omogućene.',
    'change_requires_purge' => 'Izmena ovog podešavanja zahteva :link podatke naloga.',
    'purging' => 'čišćenje',
    'warning_local_refund' => 'Povraćaj novca će biti zabeležen u aplikaciji, ali NEĆE biti procesuiran kod posrednka za plaćanje.',
    'email_address_changed' => 'Adresa e-pošte je izmenjena',
    'email_address_changed_message' => 'E-mail adresa Vašeg naloga je promenjenasa :old_email na :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Izvoz u ZIP zahteva GMP ekstenziju',
    'email_history' => 'Istorija e-poruka',
    'loading' => 'Učitavanje',
    'no_messages_found' => 'Poruke nisu pronađene',
    'processing' => 'Procesiranje',
    'reactivate' => 'Ponovo aktiviraj',
    'reactivated_email' => 'Adresa e-pošte je ponovo aktivirana',
    'emails' => 'e-poruke',
    'opened' => 'Otvorene',
    'bounced' => 'Odbijene',
    'total_sent' => 'Ukupno poslato',
    'total_opened' => 'Ukupno otvoreno',
    'total_bounced' => 'Ukupno odbijeno',
    'total_spam' => 'Ukupno SPAM',
    'platforms' => 'Platforme',
    'email_clients' => 'Pošalji e-poštu klijentima',
    'mobile' => 'Mobilni',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Grupa',
    'subgroup' => 'Podgrupa',
    'unset' => 'Nepodešeno',
    'received_new_payment' => 'Primili ste novu uplatu!',
    'slack_webhook_help' => 'Prati uplatu upotrebom linka :link',
    'slack_incoming_webhooks' => 'Dolazeće Slack webhook',
    'accept' => 'Prihvati',
    'accepted_terms' => 'Uspešno prihvaćeni aktuelni uslovi za usluge',
    'invalid_url' => 'Neispravan URL',
    'workflow_settings' => 'Podešavanje toka rada',
    'auto_email_invoice' => 'Automatsko slanje ePošte',
    'auto_email_invoice_help' => 'Automatski pošalji ponavljajuće račune u momentu kreiranja.',
    'auto_archive_invoice' => 'AAutomatsko arhiviranje',
    'auto_archive_invoice_help' => 'Automatski arhiviraj račune kada su plaćeni.',
    'auto_archive_quote' => 'Automatsko Arhiviranje',
    'auto_archive_quote_help' => 'Automatski arhiviraj ponude kada su konvertovane.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Dozvoli odobrenje istekle ponude',
    'allow_approve_expired_quote_help' => 'Dozvoli klijentima odobrenje isteklih ponuda.',
    'invoice_workflow' => 'Proces rada računa',
    'quote_workflow' => 'Proces rada ponude',
    'client_must_be_active' => 'Greška: klijent mora biti aktivan',
    'purge_client' => 'Očisti klijenta',
    'purged_client' => 'Uspešno očišćen klijent',
    'purge_client_warning' => 'Svi relevantni zapisi (računi, zadaci, troškovi, dokumenti, itd) će takože biti obrisani.',
    'clone_product' => 'Kloniraj proizvod',
    'item_details' => 'Element detalji',
    'send_item_details_help' => 'Pošalji pojedinačne stavke posredniku za plaćanje',
    'view_proposal' => 'Pogledaj ponudu',
    'view_in_portal' => 'Pogledaj u portalu',
    'cookie_message' => 'Ovaj sajt koristi kolačiće za bolju upotrebljivost našeg web sajta.',
    'got_it' => 'Shvatio!',
    'vendor_will_create' => 'dobavljač će biti kreiran',
    'vendors_will_create' => 'dobavljači će biti kreirani',
    'created_vendors' => 'Uspešno kreirano :count dobavljač(a)',
    'import_vendors' => 'Uvezi Dobavljače',
    'company' => 'Kompanija',
    'client_field' => 'Polje klijenta',
    'contact_field' => 'Polje kontakt',
    'product_field' => 'Polje proizvod',
    'task_field' => 'Polje zadatak',
    'project_field' => 'Polje Projekta',
    'expense_field' => 'Polje troškova',
    'vendor_field' => 'Polje dobavljača',
    'company_field' => 'Polje kompanija',
    'invoice_field' => 'Polje računa',
    'invoice_surcharge' => 'Višak Računa',
    'custom_task_fields_help' => 'Dodaj polje pri kreiranju zadatka.',
    'custom_project_fields_help' => 'Dodaj polje pri kreiranju projekta.',
    'custom_expense_fields_help' => 'Dodaj polje pri kreiranju troška.',
    'custom_vendor_fields_help' => 'Dodaj polje pri kreiranju dobavljača.',
    'messages' => 'Poruke',
    'unpaid_invoice' => 'Neplaćeni računi',
    'paid_invoice' => 'Plaćeni računi',
    'unapproved_quote' => 'Ne odobrene ponude',
    'unapproved_proposal' => 'Neodobrene Ponude',
    'autofills_city_state' => 'Automatsko pounjavanje grada i okruga',
    'no_match_found' => 'Nije pronađeno',
    'password_strength' => 'Jačina lozinke',
    'strength_weak' => 'Slabo',
    'strength_good' => 'Dobro',
    'strength_strong' => 'Snažno',
    'mark' => 'Označi',
    'updated_task_status' => 'Uspešno ažuriran status zadatka',
    'background_image' => 'Pozadinska fotografija',
    'background_image_help' => 'Koristite :link za uređivanje slika, preporulujemo da koristite manje datoteke.',
    'proposal_editor' => 'editor ponuda',
    'background' => 'Pozadina',
    'guide' => 'Vodič',
    'gateway_fee_item' => 'Nakndada za posrednika',
    'gateway_fee_description' => 'Dodatni trošak za posrednika',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Prikaži uplate',
    'show_aging' => 'Prikaži Starenje',
    'reference' => 'Referenca',
    'amount_paid' => 'Plaćen iznos',
    'send_notifications_for' => 'Pošalji notifikaciju za',
    'all_invoices' => 'Svi računi',
    'my_invoices' => 'Moji računi',
    'payment_reference' => 'Referenca plaćanja',
    'maximum' => 'Maksimum',
    'sort' => 'Sort',
    'refresh_complete' => 'Osvežavanje završeno',
    'please_enter_your_email' => 'Unesite adresu e-pošte',
    'please_enter_your_password' => 'Unesite lozinku',
    'please_enter_your_url' => 'Unesite web adresu',
    'please_enter_a_product_key' => 'Unesite šifru proizvoda',
    'an_error_occurred' => 'Desila se greška',
    'overview' => 'Pregled',
    'copied_to_clipboard' => 'Sadržaj :value kopiran u klipbord',
    'error' => 'Greška',
    'could_not_launch' => 'Nije moguće pokrenuti',
    'additional' => 'Dodatno',
    'ok' => 'Ok',
    'email_is_invalid' => 'Adresa e-pošte nije validna',
    'items' => 'Stavke',
    'partial_deposit' => 'Avans/Depozit',
    'add_item' => 'Dodaj stavku',
    'total_amount' => 'Ukupan iznos',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Status računa',
    'click_plus_to_add_item' => 'Kliknite + za dodavanje stavke',
    'count_selected' => ':count selektovano',
    'dismiss' => 'Odbaci',
    'please_select_a_date' => 'Izaberite datum',
    'please_select_a_client' => 'Izaberite klijenta',
    'language' => 'Jezik',
    'updated_at' => 'Ažurirano',
    'please_enter_an_invoice_number' => 'Unesite broj računa',
    'please_enter_a_quote_number' => 'Unesite broj ponude',
    'clients_invoices' => 'Računi za :client',
    'viewed' => 'Pregledano',
    'approved' => 'Odobreno',
    'invoice_status_1' => 'Nacrt',
    'invoice_status_2' => 'Poslato',
    'invoice_status_3' => 'Pregledano',
    'invoice_status_4' => 'Odobreno',
    'invoice_status_5' => 'Delimično',
    'invoice_status_6' => 'Plaćeno',
    'marked_invoice_as_sent' => 'Račun uspešno obeležen kao poslat',
    'please_enter_a_client_or_contact_name' => 'Unesite klijenta ili ime kontakta',
    'restart_app_to_apply_change' => 'Restartuje aplikaciju za aktiviranje izmene',
    'refresh_data' => 'Osveži podatke',
    'blank_contact' => 'Prazan kontakt',
    'no_records_found' => 'Nema zapisa',
    'industry' => 'Delatnost',
    'size' => 'Veličina',
    'net' => 'Čisto',
    'show_tasks' => 'Prikaži zadatke',
    'email_reminders' => 'Podsetnici e-poštom',
    'reminder1' => 'Prvi podsetnik',
    'reminder2' => 'Drugi podsetnik',
    'reminder3' => 'Treći podsetnik',
    'send' => 'Pošalji',
    'auto_billing' => 'Automatski račun',
    'button' => 'Dugme',
    'more' => 'Više',
    'edit_recurring_invoice' => 'Izmeni ponavljajući račun',
    'edit_recurring_quote' => 'Izmeni ponavljajuću ponudu',
    'quote_status' => 'Status ponude',
    'please_select_an_invoice' => 'Izaberite račun',
    'filtered_by' => 'Filter po',
    'payment_status' => 'Status plaćanja',
    'payment_status_1' => 'Na čekanju',
    'payment_status_2' => 'Storno',
    'payment_status_3' => 'Neuspešno',
    'payment_status_4' => 'Završeno',
    'payment_status_5' => 'Delimično povraćeno',
    'payment_status_6' => 'Povraćeno',
    'send_receipt_to_client' => 'Pošalji priznanicu klijentu',
    'refunded' => 'Povraćeno',
    'marked_quote_as_sent' => 'Ponuda uspešno obeležena kao poslata',
    'custom_module_settings' => 'Podešavanje dodatnih modula',
    'ticket' => 'Tiket',
    'tickets' => 'Tiketi',
    'ticket_number' => 'Tiket #',
    'new_ticket' => 'Novi tiket',
    'edit_ticket' => 'Izmeni tiket',
    'view_ticket' => 'Vidi tiket',
    'archive_ticket' => 'Arhiviraj tiket',
    'restore_ticket' => 'Vrati tiket',
    'delete_ticket' => 'Obriši tiket',
    'archived_ticket' => 'Tiket uspešno arhiviran',
    'archived_tickets' => 'Tiketi uspešno aktivirani',
    'restored_ticket' => 'TIket uspešno vraćen',
    'deleted_ticket' => 'Tiket uspešno obrisan',
    'open' => 'Otvori',
    'new' => 'Novi',
    'closed' => 'Zatvoreno',
    'reopened' => 'Ponovo otvoreno',
    'priority' => 'Prioritet',
    'last_updated' => 'Poslednja izmena',
    'comment' => 'Komentari',
    'tags' => 'Oznake',
    'linked_objects' => 'Povezani objekti',
    'low' => 'Nizak',
    'medium' => 'Srednji',
    'high' => 'Visok',
    'no_due_date' => 'Datum valute nije unet',
    'assigned_to' => 'Dodeljeno za',
    'reply' => 'Odgovor',
    'awaiting_reply' => 'Čekanje odgovora',
    'ticket_close' => 'Zatvori tiket',
    'ticket_reopen' => 'Ponovo otvori tiket',
    'ticket_open' => 'Otvori tiket',
    'ticket_split' => 'Razdvoji tiket',
    'ticket_merge' => 'Spoji tiket',
    'ticket_update' => 'Ažuriraj tiket',
    'ticket_settings' => 'Podešavanje tiketa',
    'updated_ticket' => 'Tiket ažuriran',
    'mark_spam' => 'Obeleži kao spam',
    'local_part' => 'Lokalni port',
    'local_part_unavailable' => 'Ime zauzeto',
    'local_part_available' => 'Ime dostupno',
    'local_part_invalid' => 'Nepravilno ime (samo alfanumerici, bez razmaka',
    'local_part_help' => 'Podesite lokalni port za Vašu dolazeću poštu za podršku, npr. VASE_IME@support.invoiceninja.com',
    'from_name_help' => 'Ime pošiljaoca je prepoznatljivo ime koje se prikazuje umesto adrese e-pošte, npr. Korisnički Centar',
    'local_part_placeholder' => 'VASE_IME',
    'from_name_placeholder' => 'Korisnički Centar',
    'attachments' => 'Prilozi',
    'client_upload' => 'Datoteke klijenta',
    'enable_client_upload_help' => 'Dozvoli klijentima da pošalju dokumente/priloge',
    'max_file_size_help' => 'Maksimalna veličina datoteke (KB) je ograničena Vašim post_max_size i upload_max_filesize varijablama u PHP.INI.',
    'max_file_size' => 'Maksimalna veličina datoteke',
    'mime_types' => 'Dozvoljeni tipovi',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Lista dozvoljenih tipova fajlova odvojenih zarezom, ostavte prazno za sve',
    'ticket_number_start_help' => 'Broj tiketa mora biti veći od aktuelnog broja tiketa',
    'new_ticket_template_id' => 'Novi tiket',
    'new_ticket_autoresponder_help' => 'Izborom šablona će se poslati automatski odgovor klijentu/kontaktu prilikom kreiranja novog tiketa',
    'update_ticket_template_id' => 'Pošalji tiket',
    'update_ticket_autoresponder_help' => 'Izborom šablona će se poslati automatski odgovor klijentu/kontaktu prilikom ažuriranja tiketa',
    'close_ticket_template_id' => 'Zatvoren tiket',
    'close_ticket_autoresponder_help' => 'Izborom šablona će se poslati automatski odgovor klijentu/kontaktu prilikom zatvaranja tiketa',
    'default_priority' => 'Podrazumevani prioritet',
    'alert_new_comment_id' => 'Novi komentar',
    'alert_comment_ticket_help' => 'Izborom šablona će se poslati obaveštenje (agentu) prilikom unosa komentara',
    'alert_comment_ticket_email_help' => 'Adrese e-pošte za slanje bcc kopija prilikom unosa komentara, odvojene zarezom',
    'new_ticket_notification_list' => 'Dodatna obaveštenja od novom tiketu',
    'update_ticket_notification_list' => 'Dodatna obaveštenja o novom komentaru',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Dodela tiketa',
    'alert_ticket_assign_agent_id_hel' => 'Izborom šablona će se poslati obaveštenje (agentu) prilikom dodeljivanja tiketa.',
    'alert_ticket_assign_agent_id_notifications' => 'Dodatna obaveštenja o dodeljivanju tiketa',
    'alert_ticket_assign_agent_id_help' => 'Adrese e-pošte za slanje bcc kopija prilikom dodeljivanja tiketa, odvojene zarezom',
    'alert_ticket_transfer_email_help' => 'Adrese e-pošte za slanje bcc kopija prilikom prenosa tiketa, odvojene zarezom',
    'alert_ticket_overdue_agent_id' => 'Zakasneo tiket',
    'alert_ticket_overdue_email' => 'Dodatna obeveštenja o zakasnelim tiketima',
    'alert_ticket_overdue_email_help' => 'Adrese e-pošte za slanje bcc kopija prilikom zakasnelog tiketa, odvojene zarezom',
    'alert_ticket_overdue_agent_id_help' => 'Izborom šablona će se poslati obaveštenje (agentu) kada je tiket zakasneo.',
    'ticket_master' => 'Rukovodilac Tiketa',
    'ticket_master_help' => 'Ima mogućnost da dodeljuje i prenosi tikete. Dodeljen kao podrazumevani agent za sve tikete.',
    'default_agent' => 'Podrazumevani agent',
    'default_agent_help' => 'Ako se izabere, biće automatski dodeljen za sve dolazeće tikete',
    'show_agent_details' => 'Prikaži detlje agenta u odgovorima',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Ukloni avatar',
    'ticket_not_found' => 'Tiket nije pronađen',
    'add_template' => 'Dodaj šablon',
    'ticket_template' => 'Šablon tiketa',
    'ticket_templates' => 'Šabloni tiketa',
    'updated_ticket_template' => 'Šablon tiketa ažuriran',
    'created_ticket_template' => 'Šablon tiketa kreiran',
    'archive_ticket_template' => 'Arhiviraj šablon',
    'restore_ticket_template' => 'Vrati šablon',
    'archived_ticket_template' => 'Tiket uspešno arhiviran',
    'restored_ticket_template' => 'Tiket uspešno vraćen',
    'close_reason' => 'Upišite razlog zatvaranja tiketa',
    'reopen_reason' => 'Upišite razlog ponovnog otvaranja tiketa',
    'enter_ticket_message' => 'Upišite poruku za dodati natiket',
    'show_hide_all' => 'Pokaži / Sakrij sve',
    'subject_required' => 'Naslov je obavezan',
    'mobile_refresh_warning' => 'Ukoliko koristite mobilnu aplikaciju, potrebno je da osvežite stranicu.',
    'enable_proposals_for_background' => 'Za slanje pozadnske slike :link omogući modul za ponude.',
    'ticket_assignment' => 'Tiket :ticket_number je dodeljen agentu :agent',
    'ticket_contact_reply' => 'Tiket :ticket_number je ažuriran od strane kontakta :contact',
    'ticket_new_template_subject' => 'Tiket :ticket_number je kreiran.',
    'ticket_updated_template_subject' => 'Tiket :ticket_number je ažuriran.',
    'ticket_closed_template_subject' => 'Tiket :ticket_number je zatvoren.',
    'ticket_overdue_template_subject' => 'Tiket :ticket_number je zakasneo.',
    'merge' => 'Spoji',
    'merged' => 'Spojeni',
    'agent' => 'Agent',
    'parent_ticket' => 'Nadređeni tiket',
    'linked_tickets' => 'Povezani tiket',
    'merge_prompt' => 'Unesite broj tiketa za spajanje',
    'merge_from_to' => 'Tiket #:old_ticket je spojen u Tiket #:new_ticket',
    'merge_closed_ticket_text' => 'Tiket #:old_ticket je zatvoren i spojen u Tiket #:new_ticket',
    'merge_updated_ticket_text' => 'Tiket #:old_ticket je zatvoren i spojen u ovaj tiket',
    'merge_placeholder' => 'Spoji tiket #:ticket u sledeći tiket',
    'select_ticket' => 'Izaberi tiket',
    'new_internal_ticket' => 'Novi interni tiket',
    'internal_ticket' => 'Interni tiket',
    'create_ticket' => 'Kreiraj tiket',
    'allow_inbound_email_tickets_external' => 'Novi tiketi preko e-pošte (klijent)',
    'allow_inbound_email_tickets_external_help' => 'Dozvoli klijentima da naprave tiket preko e-pošte',
    'include_in_filter' => 'Dodaj u filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Uporedi',
    'hosted_login' => 'Hostovan login',
    'selfhost_login' => 'Samohostovan login',
    'google_login' => 'Google login',
    'thanks_for_patience' => 'Hvala na stpljenju dok radimo na implementaciji ovih mogućnosti.\n\nNadamo se da će biti završeno u sledećih par meseci.\n\nDo tada ćemo nastaviti da podržavamo',
    'legacy_mobile_app' => 'nasleđenu mobilnu aplikaciju',
    'today' => 'Danas',
    'current' => 'Tekući',
    'previous' => 'Prethodni',
    'current_period' => 'Tekući period',
    'comparison_period' => 'Period za upoređivanje',
    'previous_period' => 'Prethodni period',
    'previous_year' => 'Sledeći period',
    'compare_to' => 'Uporedi sa',
    'last_week' => 'Poslednja sedmica',
    'clone_to_invoice' => 'Kloniraj u račun',
    'clone_to_quote' => 'Kloniraj u ponudu',
    'convert' => 'Konvertuj',
    'last7_days' => 'Poslednjih 7 dana',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Prilagođeni JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Prikaži detalje proizvoda',
    'show_product_notes_help' => 'Prikaži <b>opis i cenu</b> u padajućoj listi proizvoda',
    'important' => 'Važno',
    'thank_you_for_using_our_app' => 'Hvala Vam što koristite našu aplikaciju!',
    'if_you_like_it' => 'Ako Vam se dopada molimo Vas',
    'to_rate_it' => 'da je ocenite.',
    'average' => 'Prosek',
    'unapproved' => 'Neodobreno',
    'authenticate_to_change_setting' => 'Molimo Vas auotorizujte se da biste promenili ovu opciju',
    'locked' => 'Zaključano',
    'authenticate' => 'Autorizuj se',
    'please_authenticate' => 'Molimo Vas da se autorizujete',
    'biometric_authentication' => 'Biometrijska autorizacija',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Unesite Vaše ime',
    'click_plus_to_add_time' => 'Kliknite + za dodavanje vremena',
    'design' => 'Dizajn',
    'password_is_too_short' => 'Lozinka je prekratka',
    'failed_to_find_record' => 'Zapis nije pronađen',
    'valid_until_days' => 'Važi do',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Dana',
    'requires_an_enterprise_plan' => 'Zahteva Enterprise plan',
    'take_picture' => 'Fotografiši',
    'upload_file' => 'Pošalji fajl',
    'new_document' => 'Novi dokument',
    'edit_document' => 'Izmeni dokument',
    'uploaded_document' => 'Uspešno poslat dokument',
    'updated_document' => 'Uspešno ažuriran dokument',
    'archived_document' => 'Uspešno arhiviran dokument',
    'deleted_document' => 'Uspešno obrisan dokument',
    'restored_document' => 'Uspešno vraćen dokument',
    'no_history' => 'Nema istorije',
    'expense_status_1' => 'Prijavljen',
    'expense_status_2' => 'Na čekanju',
    'expense_status_3' => 'Fakturisano',
    'no_record_selected' => 'Nijedan zapis nije odabran',
    'error_unsaved_changes' => 'Molimo Vas sačuvajte ili otkažite izmene',
    'thank_you_for_your_purchase' => 'Hvala Vam na kupovini!',
    'redeem' => 'Redeem',
    'back' => 'Nazad',
    'past_purchases' => 'Ranije kupovine',
    'annual_subscription' => 'Godišnja pretplata',
    'pro_plan' => 'Pro plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count korisnika',
    'upgrade' => 'Nadogradi',
    'please_enter_a_first_name' => 'Unesite ime',
    'please_enter_a_last_name' => 'Unesite prezime',
    'please_agree_to_terms_and_privacy' => 'Molimo Vas prihvatite uslove korišćenja i politiku privatnosti da biste registrovali korisnički nalog.',
    'i_agree_to_the' => 'Slažem se sa',
    'terms_of_service_link' => 'uslovima korišćenja',
    'privacy_policy_link' => 'politikom privatnosti',
    'view_website' => 'Poseti web sajt',
    'create_account' => 'Registruj nalog',
    'email_login' => 'Prijavite se emailom',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'Prvi dan u nedelji',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
